//=============================================================================
// Spawns some explosion effects.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class SentinelComponent_ExplosionEffects extends ActorComponent
	within Sentinel;

/** Effect to spawn when exploding. */
var() ParticleSystem ExplosionTemplate;
/** Light to spawn when exploding */
var() class<UTExplosionLight> ExplosionLightClass;
/** Sound to play when exploding. */
var() SoundCue ExplosionSound;

/** Decal to project onto ground when exploded. */
var() MaterialInstance ExplosionDecal;
var() InterpCurveFloat DecalMaterialParameterCurve;
var() name DecalDissolveParamName;
var() float DecalWidth;
var() float DecalHeight;

function bool Explode(class<DamageType> KilledByDamageType)
{
	local bool bExploded;

	if(KilledByDamageType != class'DmgType_Suicided')
	{
		if(WorldInfo.NetMode != NM_DedicatedServer)
		{
			SpawnEffects();
		}

		bExploded = true;
	}

	return bExploded;
}

function SpawnEffects()
{
	local ParticleSystemComponent PSC;
	local UTExplosionLight L;
	local MaterialInstanceTimeVarying Decal;
	local float DecalDissolveStartTime;

	PSC = WorldInfo.MyEmitterPool.SpawnEmitter(ExplosionTemplate, Location, BaseComponent.Rotation);

	if(PSC != none)
	{
		AttachComponent(PSC);

		if(!WorldInfo.bDropDetail)
		{
			L = new(self) ExplosionLightClass;
			AttachComponent(L);
		}
	}

	PlaySound(ExplosionSound, true,,, Location + WeaponComponent.Translation);

	Decal = new(self) class'MaterialInstanceTimeVarying';
	Decal.SetParent(ExplosionDecal);

	WorldInfo.MyDecalManager.SpawnDecal(Decal, BaseComponent.GetPosition(), class'SUtils'.static.RotateRelative(BaseComponent.Rotation, -16384.0, 0, 0), DecalWidth, DecalHeight, 32.0, false);
	Decal.SetScalarCurveParameterValue(DecalDissolveParamName, DecalMaterialParameterCurve);
	//Start fading out just soon enough to finish fading when the decal's lifespan runs out.
	DecalDissolveStartTime = WorldInfo.MyDecalManager.DecalLifeSpan;
	DecalDissolveStartTime -= DecalMaterialParameterCurve.Points[DecalMaterialParameterCurve.Points.length - 1].InVal;
	DecalDissolveStartTime = FMax(DecalDissolveStartTime, 0.0);
	Decal.SetScalarStartTime(DecalDissolveParamName, DecalDissolveStartTime);
}

defaultproperties
{
	ExplosionTemplate=ParticleSystem'FX_VehicleExplosions.Effects.P_FX_VehicleDeathExplosion'
	ExplosionLightClass=class'UTGame.UTTankShellExplosionLight'
	ExplosionSound=SoundCue'Sentinel_Resources.Sounds.Sentinel.BExplosion3Cue'

	ExplosionDecal=MaterialInstanceTimeVarying'Sentinel_Resources.Materials.Decals.MITV_Decal_Explode'
	DecalMaterialParameterCurve=(Points=((InVal=0.0,OutVal=0.0),(InVal=4.0,OutVal=1.0)))
	DecalDissolveParamName=DissolveAmount
	DecalWidth=256.0
	DecalHeight=256.0
}