//=============================================================================
// Handles rotation sounds for a Sentinel.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class SentinelComponent_RotationSound extends AudioComponent;

/** Rotation speed that results in 1.0 pitch for rotation sounds. */
var() float RotationSoundPitchScale;
/** Rotation speed that results in 1.0 volume for rotation sounds. */
var() float RotationSoundVolumeScale;
/** Upper limit on rotation sound volume. */
var() float RotationSoundVolumeMax;
/** Name of parameter to change motor sound */
var() name RotationSoundParamName;
/** Default motor sound. */
var() SoundNodeWave RotationSoundNodeWave;

/** Time constant for calculating average rotation speeds. */
var() float AverageDeltaRotationTime;

/** The average change in rotation per second. */
var float AverageDeltaRotation;

function Initialize()
{
	SetWaveParameter(RotationSoundParamName, RotationSoundNodeWave);
	RotationSoundVolumeScale = default.RotationSoundVolumeScale;
	RotationSoundVolumeMax = default.RotationSoundVolumeMax;
}

/**
 * Sets pitch and volume based on average rotation speed.
 */
function AdjustRotationSounds(float DeltaTime, float DeltaRotation)
{
	AverageDeltaRotation -= AverageDeltaRotation * (DeltaTime / AverageDeltaRotationTime);
	AverageDeltaRotation += Abs(DeltaRotation) / AverageDeltaRotationTime;
	PitchMultiplier = AverageDeltaRotation / RotationSoundPitchScale;
	VolumeMultiplier = FMin(AverageDeltaRotation / RotationSoundVolumeScale, RotationSoundVolumeMax);
}

/**
 * Changes the rotation sound.
 */
function ChangeSound(SoundNodeWave NewSound)
{
	SetWaveParameter(RotationSoundParamName,  NewSound);
}

/**
 * Scales max volume and the speed needed to reach that volume.
 */
function ModifyVolumeParameters(float VolumeParameterModifier)
{
	RotationSoundVolumeScale = default.RotationSoundVolumeScale / VolumeParameterModifier;
	RotationSoundVolumeMax = default.RotationSoundVolumeMax * VolumeParameterModifier;
}

defaultproperties
{
	RotationSoundPitchScale=7000.0
	RotationSoundVolumeScale=1800.0
	RotationSoundVolumeMax=2.0
	RotationSoundParamName=MotorSound
	RotationSoundNodeWave=SoundNodeWave'A_Vehicle_SPMA.Sounds.A_Vehicle_SPMA_CannonRotate01'
	AverageDeltaRotationTime=0.1

	SoundCue=SoundCue'Sentinel_Resources.Sounds.Sentinel.Motor'
	bShouldRemainActiveIfDropped=true
	bStopWhenOwnerDestroyed=true
	bAutoPlay=true
	VolumeMultiplier=0.0
}