//=============================================================================
// Allows mappers to configure Sentinels per map.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class SentinelConfigurationActor extends Info
	implements(SentinelConfigurationProvider)
	placeable
	hidecategories(Physics);

/** Deployer is not allowed to upgrade if this is false. */
var() bool bAllowUpgrades;
/** Maximum number of Sentinels each player can have deployed at once. */
var() int MaxCannon;
/** Maximum number of Sentinels for all players in a team */
var() int MaxTeamCannon;
/** Biggest difference allowed in number of Sentinels deployed for each team. */
var() int MaxTeamAdvantageCannon;

/** Class to spawn for precaching purposes. */
var() editconst class<SentinelPrecachingActor> PrecachingActorClass;
var SentinelPrecachingActor PrecachingActor;

/** Class of objective to spawn to handle drawing Sentinel icons on the map. */
var() editconst class<SentinelDummyObjective> DummyObjectiveClass;
var SentinelDummyObjective DummyObjective;

function PostBeginPlay()
{
	super.PostBeginPlay();

	PrecachingActor = PrecachingActorClass.static.CreatePrecachingActor(WorldInfo);
	DummyObjective = DummyObjectiveClass.static.CreateDummyObjective(WorldInfo);
}

function bool GetAllowUpgrades()
{
	return bAllowUpgrades;
}

function int GetMaxCannon()
{
	return MaxCannon;
}

function int GetMaxTeamCannon()
{
	return MaxTeamCannon;
}

function int GetMaxTeamAdvantageCannon()
{
	return MaxTeamAdvantageCannon;
}

function float GetProviderPriority()
{
	return 1.0;
}

defaultproperties
{
	bAllowUpgrades=true
	MaxCannon=3
	MaxTeamCannon=16
	MaxTeamAdvantageCannon=3

	PrecachingActorClass=class'SentinelPrecachingActor'
	DummyObjectiveClass=class'SentinelDummyObjective'
}