//=============================================================================
// Provides functions to get configurable properties for using Sentinels.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
interface SentinelConfigurationProvider;

/**
 * Whether or not Deployer is not allowed to upgrade Sentinels.
 */
function bool GetAllowUpgrades();

/**
 * Maximum number of Sentinels each player can have deployed at once.
 */
function int GetMaxCannon();

/**
 * Maximum total Sentinels for all players in a team at once.
 */
function int GetMaxTeamCannon();

/**
 * Biggest difference allowed in number of Sentinels deployed for each team.
 */
function int GetMaxTeamAdvantageCannon();

/**
 * Priority of this provider in case multiple providers exist at once.
 * Settings should only be read from the provider with the highest priority.
 * If multiple providers of the same priority exist then precedence is undefined.
 */
function float GetProviderPriority();