//=============================================================================
// Targeting an allied vehicle to heal it, presumably with a Link beam.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class SentinelControllerComponent_Behaviour_HealingVehicle extends SentinelControllerComponent_Behaviour_TargetingPawn;

function bool PossiblyTarget(Pawn PotentialTarget, optional int ExtraWeight)
{
	if(PotentialTarget == none || PotentialTarget.bDeleteMe || PotentialTarget.Health <= 0 || PotentialTarget.DrivenVehicle != none)
		return false;

	//Only target healable vehicles.
	if(!CanHeal(UTVehicle(PotentialTarget)))
		return false;

	//Don't target pawns outside of range.
	if(VSize(PotentialTarget.Location - Cannon.Location) > Cannon.GetRange())
		return false;

	//Always change if current target is dead or nonexistent.
	if(Enemy == none || Enemy.Health <= 0)
		return true;

	//Keep healing until they go away.
	if(PotentialTarget == Enemy)
		return true;

	//Change if new target is more important than current target.
	if(PawnTargetPriority(PotentialTarget, ExtraWeight) > PawnTargetPriority(Enemy))
		return true;

	return false;
}

function bool CanHeal(UTVehicle UTV)
{
	if(UTV == none)
		return false;

	//Only target linkable vehicles.
	if(!UTV.bValidLinkTarget || UTV.LinkHealMult <= 0.0)
		return false;

	//Can't heal vehicles that are already at full health.
	if(UTV.Health >= UTV.HealthMax)
		return false;

	//Only target allied vehicles.
	if(!Cannon.IsSameTeam(UTV))
		return false;

	return true;
}

defaultproperties
{
	LoseInterestTime=1.3
	DamageCauserExtraWeight=0.0
	IgnoredDamageTypes.Empty()
}