//=============================================================================
// Loads all relevant Sentinel classes to ensure that a "cached shader map"
// exists for all materials that they reference, to avoid long hitches.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class SentinelPrecachingActor extends Info;

var class<UTUIDataStore_SentinelUpgrades> UpgradeDataStoreClass;
var array< class<SentinelUpgrade> > UpgradeClasses, WeaponClasses;

simulated function PostBeginPlay()
{
	//`log("Precaching:"@self);
	UpgradeClasses = UpgradeDataStoreClass.static.LoadUpgradeClasses('Upgrades');
	WeaponClasses = UpgradeDataStoreClass.static.LoadUpgradeClasses('Weapons');
}

/**
 * Finds a preexisting instance of this class if one exists, or spawns a new one if not.
 *
 * @return	an instance of this class.
 */
static final function SentinelPrecachingActor CreatePrecachingActor(WorldInfo WI)
{
	local SentinelPrecachingActor PrecachingActor;

	foreach WI.DynamicActors(class'SentinelPrecachingActor', PrecachingActor)
	{
		`log("Found PrecachingActor:"@PrecachingActor);
		break;
	}

	if(PrecachingActor == none)
	{
		PrecachingActor = WI.Spawn(default.Class);
		`log("Spawned PrecachingActor:"@PrecachingActor);
	}

	return PrecachingActor;
}

defaultproperties
{
	UpgradeDataStoreClass=class'UTUIDataStore_SentinelUpgrades'

	RemoteRole=ROLE_SimulatedProxy
	bAlwaysRelevant=true
	bNetTemporary=true
	bStatic=false
	bNoDelete=false
}