//=============================================================================
// Bouncy bouncy.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class SentinelProjectile_Grenade extends SentinelProjectile;

var const StaticMeshComponent Mesh;
var const LightEnvironmentComponent LightEnvironment;
var() SentinelProjectileComponent_Physics PhysicsComponent;

/**
 * Set the initial velocity and cook time
 */
simulated function PostBeginPlay()
{
	super.PostBeginPlay();

	SetTimer(2.5 + FRand() * 0.5, false);
	RandSpin(100000);
}

function Init(Vector Direction)
{
	SetRotation(Rotator(Direction));
	Velocity = Speed * Direction;
}

simulated function Timer()
{
	Explode(Location, Normal(Velocity));
}

simulated event HitWall(Vector HitNormal, Actor Wall, PrimitiveComponent WallComp)
{
	bBlockedByInstigator = true;

	if(WorldInfo.NetMode != NM_DedicatedServer && ImpactSound != none)
	{
		PlaySound(ImpactSound, true);
	}

	if(Pawn(Wall) == none)
	{
		PhysicsComponent.Bounce(HitNormal);

		if(VSize(Velocity) < 20)
		{
			ImpactedActor = Wall;
			Explode(Location, HitNormal);
		}
	}
	else if(Wall != Instigator)
	{
		Explode(Location, HitNormal);
	}
}

simulated function PhysicsVolumeChange(PhysicsVolume NewVolume)
{
	super.PhysicsVolumeChange(NewVolume);

	PhysicsComponent.PhysicsVolumeChange(NewVolume);
}

defaultproperties
{
	ProjExplosionTemplate=ParticleSystem'WP_RocketLauncher.Effects.P_WP_RocketLauncher_RocketExplosion'
	ExplosionLightClass=class'UTGame.UTRocketExplosionLight'

	Speed=1000.0
	MaxSpeed=1000.0
	Damage=110.0
	DamageRadius=250
	MomentumTransfer=50000
	MyDamageType=class'UTDmgType_SentinelGrenade'
	LifeSpan=3.0
	ExplosionSound=SoundCue'A_Weapon_RocketLauncher.Cue.A_Weapon_RL_Impact_Cue'
	ExplosionDecal=MaterialInstanceTimeVarying'WP_RocketLauncher.Decals.MITV_WP_RocketLauncher_Impact_Decal01'
	DecalWidth=128.0
	DecalHeight=128.0
	bCollideWorld=true
	bBounce=true
	Physics=PHYS_Falling
	CheckRadius=36.0

	ImpactSound=SoundCue'A_Weapon_RocketLauncher.Cue.A_Weapon_RL_GrenadeFloor_Cue'

	bNetTemporary=false
	bWaitForEffects=false

	CustomGravityScaling=0.5

	Begin Object Class=DynamicLightEnvironmentComponent Name=LightEnvironment0
 		bCastShadows=false
		bDynamic=true
		AmbientGlow=(R=0.2,G=0.2,B=0.2)
		MinTimeBetweenFullUpdates=0.2
 	End Object
 	LightEnvironment=LightEnvironment0
 	Components.Add(LightEnvironment0)

	Begin Object Class=StaticMeshComponent Name=ProjectileMesh
		StaticMesh=StaticMesh'LT_Mech.SM.Mesh.S_LT_Mech_SM_Techcylinder02a'
		LightEnvironment=LightEnvironment0
		Scale=0.25
		Rotation=(Pitch=16384,Yaw=0,Roll=0)
		Translation=(X=8.0,Y=0.0,Z=0.0)
		CullDistance=12000
		CastShadow=false
		bUseAsOccluder=false
		BlockRigidBody=false
		BlockNonZeroExtent=false
		BlockZeroExtent=false
		BlockActors=false
		CollideActors=false
	End Object
	Mesh=ProjectileMesh
	Components.Add(ProjectileMesh)

	Begin Object Class=SentinelProjectileComponent_Physics Name=PhysicsComponent0
		BounceRandomness=0.25
		BounceDamping=0.3
		BounceAngle=1.7
		EnterWaterDamping=0.8
		WaterAccelRate=0.0
		WaterMaxSpeed=500.0
		WaterEntrySound=SoundCue'Sentinel_Resources.Sounds.Weapons.RocketSplashCue'
		WaterEntryEffect=ParticleSystem'Sentinel_Resources.Effects.Misc.P_Splash'
		WaterExitSound=SoundCue'Sentinel_Resources.Sounds.Weapons.RocketSplashCue'
		WaterExitEffect=ParticleSystem'Sentinel_Resources.Effects.Misc.P_Splash'
	End Object
	PhysicsComponent=PhysicsComponent0
}