//=============================================================================
// Remarkably like a Link projectile.
// TODO: Ambient sound?
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class SentinelProjectile_Pulse extends SentinelProjectile;

var repnotify LinearColor ProjColour;
var Vector VectColour;

replication
{
	if(Role == ROLE_Authority && bNetDirty)
		ProjColour;
}

simulated event ReplicatedEvent(name VarName)
{
	if(VarName == 'ProjColour')
	{
		SetColour(ProjColour);
	}
	else
	{
		super.ReplicatedEvent(VarName);
	}
}

/**
 * Sets colour to use for projectile and effects.
 */
simulated function SetColour(LinearColor NewColour)
{
	ProjColour = NewColour;

	VectColour.X = ProjColour.R;
	VectColour.Y = ProjColour.G;
	VectColour.Z = ProjColour.B;

	if(ProjEffects != none)
	{
		ProjEffects.SetVectorParameter('LinkProjectileColor', VectColour);
	}

	if(ProjectileLight != none)
	{
		ProjectileLight.SetLightProperties(ProjectileLight.Brightness, class'SUtils'.static.LinearColorToColor(ProjColour), ProjectileLight.Function);
	}
}

simulated function SetExplosionEffectParameters(ParticleSystemComponent ProjExplosion)
{
	super.SetExplosionEffectParameters(ProjExplosion);

	if(ProjExplosion != none)
	{
		ProjExplosion.SetVectorParameter('LinkImpactColor', VectColour);
	}
}

defaultproperties
{
	ProjColour=(R=0.4,G=0.6,B=0.7)

	ProjFlightTemplate=ParticleSystem'WP_LinkGun.Effects.P_WP_Linkgun_Projectile'
	ProjExplosionTemplate=ParticleSystem'Sentinel_Resources.Effects.Weapons.P_PulseCannon_Projectile_Impact'
	ExplosionSound=SoundCue'A_Weapon_Link.Cue.A_Weapon_Link_ImpactCue'
	MaxEffectDistance=7000.0
	ProjectileLightClass=class'ProjectileLight_Pulse'
	bProjectileLight=false

	Speed=2000.0
	MaxSpeed=2000.0
	AccelRate=0.0

	Damage=40
	DamageRadius=0.0
	MomentumTransfer=30000.0
	NetCullDistanceSquared=144000000.0

	MyDamageType=class'UTDmgType_SentinelPulse'
	LifeSpan=4.5

	bCollideWorld=true
	DrawScale=1.8
}