//=============================================================================
// A little rocket. Split into multiple classes purely to make it possible to
// stop the trail emitter from following the rocket after the motor turns off.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class SentinelProjectile_Rocket_Base extends SentinelProjectile;

var() SentinelProjectileComponent_Physics PhysicsComponent;

/** Sound to replace ExplosionSound when underwater. */
var() SoundCue UnderwaterExplosionSound;
/** Explosion effect to use when underwater. */
var() ParticleSystem UnderwaterExplosionTemplate;

simulated function PhysicsVolumeChange(PhysicsVolume NewVolume)
{
	super.PhysicsVolumeChange(NewVolume);

	PhysicsComponent.PhysicsVolumeChange(NewVolume);

	if(NewVolume.bWaterVolume)
	{
		ExplosionSound = UnderwaterExplosionSound;
		ProjExplosionTemplate = UnderwaterExplosionTemplate;
	}
	else
	{
		ExplosionSound = default.ExplosionSound;
		ProjExplosionTemplate = default.ProjExplosionTemplate;
	}
}

defaultproperties
{
	UnderwaterExplosionSound=SoundCue'Sentinel_Resources.Sounds.Weapons.PepperPotRocketBubbleCue'
	UnderwaterExplosionTemplate=ParticleSystem'Sentinel_Resources.Effects.Weapons.P_SentinelRocket_Explosion_Underwater'

	ProjFlightTemplate=ParticleSystem'Sentinel_Resources.Effects.Weapons.P_SentinelRocket_Trail'
	AmbientSound=SoundCue'Sentinel_Resources.Sounds.Weapons.PepperPotRocketAmbientCue'
	ProjExplosionTemplate=ParticleSystem'Sentinel_Resources.Effects.Weapons.P_SentinelRocket_Explosion'

	ExplosionDecal=MaterialInstanceTimeVarying'WP_RocketLauncher.Decals.MITV_WP_RocketLauncher_Impact_Decal01'
	DecalWidth=64.0
	DecalHeight=64.0

	Speed=300.0
	AccelRate=3000.0
	MaxSpeed=2000.0

	Damage=10.0
	DamageRadius=150.0
	MomentumTransfer=20000
	MyDamageType=class'UTDmgType_SentinelRocket'

	LifeSpan=10.0

	ExplosionSound=SoundCue'Sentinel_Resources.Sounds.Weapons.PepperPotRocketBangCue'

	bCollideWorld=true
	CheckRadius=10.0

	ExplosionLightClass=class'UTExplosionLight_SentinelRocket'

	bWaitForEffects=true
	bAttachExplosionToVehicles=false
	bRotationFollowsVelocity=true

	Begin Object Class=StaticMeshComponent Name=ProjectileMesh
		StaticMesh=StaticMesh'VH_Cicada.Mesh.S_VH_Cicada_Rocket'
		Scale=0.4
		CullDistance=12000
		CastShadow=false
		bUseAsOccluder=false
		bAcceptsLights=false
		BlockRigidBody=false
		BlockNonZeroExtent=false
		BlockZeroExtent=false
		BlockActors=false
		CollideActors=false
	End Object
	Components.Add(ProjectileMesh)

	Begin Object Class=SentinelProjectileComponent_Physics Name=PhysicsComponent0
		EnterWaterDamping=0.8
		WaterAccelRate=0.0
		WaterMaxSpeed=500.0
		WaterEntrySound=SoundCue'Sentinel_Resources.Sounds.Weapons.RocketSplashCue'
		WaterEntryEffect=ParticleSystem'Sentinel_Resources.Effects.Misc.P_Splash'
		WaterExitSound=SoundCue'Sentinel_Resources.Sounds.Weapons.RocketSplashCue'
		WaterExitEffect=ParticleSystem'Sentinel_Resources.Effects.Misc.P_Splash'
	End Object
	PhysicsComponent=PhysicsComponent0
}
