//=============================================================================
// Absorbs a fraction of damage.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class SentinelUpgrade_Armour extends SentinelUpgrade;

/** Damage that armour can absorb before being destroyed. */
var() float ArmourAmount;
/** Proportion of damage absorbed. */
var() float ProtectionFactor;

simulated function GetStatusText(out array<String> StatusStrings)
{
	local String StatusLine;

	StatusLine = class'UIStrings'.default.Armour$": ";
	class'SUtils'.static.PadWithSpaces(StatusLine, 15);
	StatusLine $= class'SUtils'.static.RedGreenTextColourMarkup(ArmourAmount, default.ArmourAmount);
	StatusLine $= int((ArmourAmount / default.ArmourAmount) * 100.0)$"%";
	StatusLine $= class'SUtils'.static.TextColourMarkup(1.0, 1.0, 1.0);
	StatusStrings[StatusStrings.Length] = StatusLine;

	super.GetStatusText(StatusStrings);
}

function NotifyTakeDamage(out int Damage, Controller InstigatedBy, vector HitLocation, vector Momentum, class<DamageType> DamageType)
{
	local float AbsorbedDamage;

	super.NotifyTakeDamage(Damage, InstigatedBy, HitLocation, Momentum, DamageType);

	AbsorbedDamage = Min(ArmourAmount, Damage * ProtectionFactor);

	Damage -= AbsorbedDamage;
	ArmourAmount -= AbsorbedDamage;

	if(ArmourAmount <= 0)
	{
		Cannon.UpgradeManager.RemoveUpgrade(self);
	}
}

function int AmmoValue()
{
	return super.AmmoValue() * (ArmourAmount / default.ArmourAmount);
}

defaultproperties
{
	FriendlyName="Armour Plating"
	Description="Constructed from a highly elastic, yet hard metal straight from Evil Corp's R&D department, these lightweight armour plates will help to reduce the damage inflicted on your Sentinel. Tests indicate an absorption of approximately 30%. Internal fitting means the original appearance of your Sentinel is preserved.\n\nThe standard deployer is not equipped to repair armour of this category and so it will need to be replaced completely when it finally wears out."

	ArmourAmount=300.0
	ProtectionFactor=0.3

	AmmoCost=50
	ActivateSound=SoundCue'Sentinel_Resources.Sounds.Upgrades.ArmorSndCue'
}
