//=============================================================================
// Increases Sentinel rotation speed.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class SentinelUpgrade_Motors extends SentinelUpgrade;

/** Factor to increase rotation speed by. */
var() float SpeedBoost;
/** New sound for motors. */
var() SoundNodeWave MotorSound;
/** Both volume scale and maximum volume are modified by this. */
var() float VolumeMultiplier;

function InitializeFor(Sentinel S)
{
	super.InitializeFor(S);

	Cannon.MaxRotationSpeed *= SpeedBoost;
	Cannon.AutoRotateRate *= SpeedBoost;
	Cannon.RotationDampingThreshold /= SpeedBoost;
}

simulated function ClientInitializeFor()
{
	super.ClientInitializeFor();

	Cannon.PitchSoundComponent.ChangeSound(MotorSound);
	Cannon.PitchSoundComponent.ModifyVolumeParameters(VolumeMultiplier);
	Cannon.YawSoundComponent.ChangeSound(MotorSound);
	Cannon.YawSoundComponent.ModifyVolumeParameters(VolumeMultiplier);
}

function OnDetach()
{
	Cannon.MaxRotationSpeed = Cannon.default.MaxRotationSpeed;
	Cannon.AutoRotateRate = Cannon.default.AutoRotateRate;
	Cannon.RotationDampingThreshold = Cannon.default.RotationDampingThreshold;

	Cannon.PitchSoundComponent.Initialize();
	Cannon.YawSoundComponent.Initialize();

	super.OnDetach();
}

//TODO: This will only work if the upgrade is destroyed after being detached.
simulated function Destroyed()
{
	if(Role < ROLE_Authority && Cannon != none)
	{
		Cannon.PitchSoundComponent.Initialize();
		Cannon.YawSoundComponent.Initialize();
	}
}

defaultproperties
{
	FriendlyName="Organic Motors"
	Description="Top-of-the-line organic motors, far more efficient than the standard electric motors. Fitted with these, a Sentinel will be able to aim faster and more accurately than before.\n\nIt is recommeded that the motors be fed with a high-quality dog food once a week. The estimated lifespan is 20 years, although some degredation in performace can be expected past 15 years."

	SpeedBoost=1.3
	MotorSound=SoundNodeWave'A_Vehicle_SPMA.Sounds.A_Vehicle_SPMA_TurretRotate01'
	VolumeMultiplier=0.6

	AmmoCost=30
	ActivateSound=SoundCue'Sentinel_Resources.Sounds.Upgrades.MotorActivateCue'
}
