//=============================================================================
// Improves Sentinels' ability to detect enemies.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class SentinelUpgrade_Sensors extends SentinelUpgrade;

/** Factor to increase sight range by. */
var() float SightRadiusBoost;
/** Amount to add to cosine of peripheral vision i.e. negative numbers improve it. */
var() float PeripheralVisionBoost;
/** Factor to increase hearing radius by. */
var() float HearingThresholdBoost;

function InitializeFor(Sentinel S)
{
	super.InitializeFor(S);

	Cannon.SightRadius *= SightRadiusBoost;
	Cannon.PeripheralVision = FMax(Cannon.PeripheralVision + PeripheralVisionBoost, -1.0);
	Cannon.HearingThreshold *= HearingThresholdBoost;
}

function OnDetach()
{
	Cannon.SightRadius = Cannon.default.SightRadius;
	Cannon.PeripheralVision = Cannon.default.PeripheralVision;
	Cannon.HearingThreshold = Cannon.default.HearingThreshold;

	super.OnDetach();
}

defaultproperties
{
	FriendlyName="Enhanced Sensors"
	Description="A set of high sensitivity audio and visual sensors. Allows more accurate target detection over a wider angle and greater range than the standard sensors."

	SightRadiusBoost=1.3
	PeripheralVisionBoost=-0.5
	HearingThresholdBoost=1.3

	AmmoCost=40
	ActivateSound=SoundCue'Sentinel_Resources.Sounds.Upgrades.SensorActivateCue'
}
