//=============================================================================
// Sprays out flame "projectiles" at a high rate.
// TODO: Maybe burst into flames when Sentinel is destroyed.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class SentinelWeapon_Flamethrower extends SentinelWeapon;

/** Looping sound to play while active. */
var() SoundCue PilotLightSound;
var AudioComponent AmbientSound;

var repnotify bool bDeactivatePilotLight;

replication
{
	if(Role == ROLE_Authority && bNetDirty)
		bDeactivatePilotLight;
}

simulated event ReplicatedEvent(name VarName)
{
	if(VarName == 'bDeactivatePilotLight')
	{
		if(bDeactivatePilotLight)
		{
			DeactivatePilotLight();
		}
	}
	else
	{
		super.ReplicatedEvent(VarName);
	}
}

/**
 * Turns on the pilot light sound.
 */
simulated function ActivatePilotLight()
{
	AmbientSound = Cannon.CreateAudioComponent(PilotLightSound, false, true);

	if(AmbientSound != none)
	{
		AmbientSound.FadeIn(ActivateSound.GetCueDuration(), 1.0);
		AmbientSound.bAutoDestroy = true;
		AmbientSound.bStopWhenOwnerDestroyed = true;
	}

	bDeactivatePilotLight = false;
}

/**
 * Turns off the pilot light sound.
 */
simulated function DeactivatePilotLight()
{
	if(AmbientSound != none)
	{
		AmbientSound.FadeOut(ActivateSound.GetCueDuration(), 0.0);
		AmbientSound.bStopWhenOwnerDestroyed = false;
		AmbientSound = none;
	}

	bDeactivatePilotLight = true;
}

function NotifyDied(Controller Killer, out class<DamageType> DamageType, Vector HitLocation)
{
	super.NotifyDied(Killer, DamageType, HitLocation);

	DeactivatePilotLight();
}

simulated function InitMuzzleFlash()
{
	super.InitMuzzleFlash();

	DeactivatePilotLight();
	ActivatePilotLight();
}

function bool FireAt(Vector Start, Rotator BarrelDir, Vector End)
{
	local Vector X, Y, Z;
	local Vector SpawnLocation;
	local Projectile Proj;
	local bool bFired;

	GetAxes(BarrelDir, X, Y, Z);
	SpawnLocation = Start;
	SpawnLocation += X * FireInfo.FireOffset.X;
	SpawnLocation += Y * FireInfo.FireOffset.Y;
	SpawnLocation += Z * FireInfo.FireOffset.Z;

	Proj = Cannon.Spawn(FireInfo.ProjectileClass, Cannon,, SpawnLocation, BarrelDir);

	if(Proj != none)
	{
		InitializeProjectile(Proj, Vector(BarrelDir));
		bFired = super.FireAt(Start, BarrelDir, End);
	}

	return bFired;
}

simulated function Destroyed()
{
	super.Destroyed();

	DeactivatePilotLight();
}

defaultproperties
{
	FriendlyName="Flamethrower"
	Description="Originally developed to control infestations of Skaarj pupae, the flamethrower is a popular attachment that will prove useful anywhere that a Sentinel must engage targets at close range. Effectiveness is high against all target types."

	WeaponMesh=SkeletalMesh'Sentinel_Resources.Meshes.Weapons.SK_Flamethrower'
	PhysicsAsset=PhysicsAsset'Sentinel_Resources.Physics.SK_Flamethrower_Physics'
	WeaponMaterial=MaterialInstance'Sentinel_Resources.Materials.Sentinel.MI_Sentinel'
	WeaponSpawnMaterial=MaterialInstance'Sentinel_Resources.Materials.Sentinel.MI_Sentinel_Spawn'
	WeaponDeadMaterial=MaterialInstance'Sentinel_Resources.Materials.Sentinel.MI_Sentinel_Dead'
	WeaponScale=0.6

	ActivateSound=SoundCue'Sentinel_Resources.Sounds.Weapons.PilotLightOnCue'
	PilotLightSound=SoundCue'Sentinel_Resources.Sounds.Weapons.PilotLightLoopCue'

	ExtraStrength=0.2
	AmmoCost=30
	CompatibleSentinels.Remove(class'Sentinel_Ceiling')

	Begin Object Class=SentinelWeaponComponent_FireInfo Name=FireInfo0
		FireInterval=0.2
		ProjectileClass=class'SentinelProjectile_Flame'
		FireOffset=(X=0.0,Y=0.0,Z=0.0)
		MaxAimError=30.0
	End Object
	FireInfo=FireInfo0

	Begin Object Class=SentinelWeaponComponent_MuzzleFlash Name=MuzzleFlash0
		Template=ParticleSystem'Sentinel_Resources.Effects.Weapons.P_Flame_Muzzle'
		MuzzleFlashDuration=0.3
		bConstantFlash=true
		MuzzleFlashOffset=(X=5.0,Y=0.0,Z=0.0)
	End Object
	MuzzleFlash=MuzzleFlash0

	Begin Object Class=SentinelWeaponComponent_MuzzleFlashLight Name=MuzzleFlashLightComponent0
		LightOffset=(X=64.0,Y=0.0,Z=0.0)
		TimeShift=((StartTime=0.0,Radius=200,Brightness=5,LightColor=(R=255,G=190,B=96,A=255)),(StartTime=2.0,Radius=64,Brightness=0,LightColor=(R=255,G=80,B=0,A=255)))
	End Object
	MuzzleFlashLight=MuzzleFlashLightComponent0
}
