//=============================================================================
// Throws down a bunch of grenades when someone approaches.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class SentinelWeapon_GrenadeLauncher extends SentinelWeapon;

/** Number of grenades to fire in one go. */
var() int GrenadeQuantity;
/** Grenades are fired at this pitch (remember that positive pitch is down relative to a Ceiling Sentinel). */
var() float LaunchAngle;

simulated function ClientInitializeFor()
{
	//Sentinel doesn't need to pitch with this weapon, as it fires in all directions at once.
	Cannon.MaxPitch = 0;
	Cannon.MinPitch = 0;

	super.ClientInitializeFor();
}

simulated function Destroyed()
{
	if(Cannon != none)
	{
		Cannon.MaxPitch = Cannon.default.MaxPitch;
		Cannon.MinPitch = Cannon.default.MinPitch;
	}
}

function bool FireAt(Vector Start, Rotator BarrelDir, Vector End)
{
	local Rotator LaunchRotation;
	local Vector X, Y, Z;
	local Vector SpawnLocation;
	local Projectile Proj;
	local int i;
	local bool bFired;

	//Fire grenades radially.
	for(i = 0; i < GrenadeQuantity; i++)
	{
		LaunchRotation = class'SUtils'.static.RotateRelative(BarrelDir, 0, (65536.0 / GrenadeQuantity) * i, 0);
		LaunchRotation = class'SUtils'.static.RotateRelative(LaunchRotation, LaunchAngle, 0, 0);
		GetAxes(LaunchRotation, X, Y, Z);
		SpawnLocation = Start;
		SpawnLocation += X * FireInfo.FireOffset.X;
		SpawnLocation += Y * FireInfo.FireOffset.Y;
		SpawnLocation += Z * FireInfo.FireOffset.Z;

		Proj = Cannon.Spawn(FireInfo.ProjectileClass, Cannon,, SpawnLocation, LaunchRotation);

		if(Proj != none)
		{
			InitializeProjectile(Proj, Vector(LaunchRotation));
			bFired = true;
		}
	}

	if(bFired)
	{
		super.FireAt(Start, BarrelDir, End);
	}

	return bFired;
}

defaultproperties
{
	FriendlyName="Grenade Launcher"
	Description="Designed for area denial, the omnidirectional grenade launcher module holds eight concussion grenades which are launched radially around the Sentinel, protecting the entire surrounding area.\n\nDue to the short effective range, it is recommended that the module only be employed from a well covered position and away from pets."

	GrenadeQuantity=8
	LaunchAngle=8192.0

	WeaponMesh=SkeletalMesh'Sentinel_Resources.Meshes.Weapons.SK_GrenadeLauncher'
	PhysicsAsset=PhysicsAsset'Sentinel_Resources.Physics.SK_GrenadeLauncher_Physics'
	WeaponMaterial=MaterialInstance'Sentinel_Resources.Materials.Weapons.MI_GrenadeLauncher'
	WeaponSpawnMaterial=MaterialInstance'Sentinel_Resources.Materials.Weapons.MI_GrenadeLauncher_Spawn'
	WeaponDeadMaterial=MaterialInstance'Sentinel_Resources.Materials.Weapons.MI_GrenadeLauncher_Dead'
	WeaponScale=1.0
	RootBone=Bottom

	//TODO: New sounds.
	ActivateSound=SoundCue'A_Weapon_RocketLauncher.Cue.A_Weapon_RL_Raise_Cue'

	ExtraStrength=0.3
	AmmoCost=40
	CompatibleSentinels.Remove(class'Sentinel_Floor')

	Begin Object Class=SentinelWeaponComponent_FireInfo Name=FireInfo0
		FireInterval=2.0
		ProjectileClass=class'SentinelProjectile_Grenade'
		FireOffset=(X=10.0,Y=0.0,Z=0.0)
		MaxRange=1200.0
		FireSound=SoundCue'A_Weapon_RocketLauncher.Cue.A_Weapon_RL_GrenadeFire_Cue'
		MaxAimError=360.0
	End Object
	FireInfo=FireInfo0
}
