//=============================================================================
// Fires high-momentum projectiles.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class SentinelWeapon_MOG extends SentinelWeapon;

function bool FireAt(Vector Start, Rotator BarrelDir, Vector End)
{
	local Vector Aim;
	local Vector X, Y, Z;
	local Vector SpawnLocation;
	local Projectile Proj;
	local bool bFired;

	Aim = Normal(End - Start);
	GetAxes(BarrelDir, X, Y, Z);

	SpawnLocation = Start;
	SpawnLocation += X * FireInfo.FireOffset.X;
	SpawnLocation += Y * FireInfo.FireOffset.Y;
	SpawnLocation += Z * FireInfo.FireOffset.Z;

	Proj = Cannon.Spawn(FireInfo.ProjectileClass, Cannon,, SpawnLocation, Rotator(Aim));

	if(Proj != none)
	{
		InitializeProjectile(Proj, Aim);
		bFired = super.FireAt(Start, BarrelDir, End);
	}

	return bFired;
}

defaultproperties
{
	FriendlyName="MOG"
	Description="The Mass Oscillation Generator creates dense projectiles of negative mass, which strongly repel any normal mass in proximity. Normally unstable, the negative mass is kept in a tenuous equilibrium sufficient to give a large effective range in the absence of obstacles. The repulsive force is stronger on more massive objects, creating some spectacular interactions.\n\nThe reduced lethality of the MOG makes it ideal for crowd pacification with minimal risk of lawsuits."

	WeaponMesh=SkeletalMesh'Sentinel_Resources.Meshes.Weapons.SK_MOG'
	PhysicsAsset=PhysicsAsset'Sentinel_Resources.Physics.SK_MOG_Physics'
	WeaponMaterial=MaterialInstance'Sentinel_Resources.Materials.Sentinel.MI_Sentinel'
	WeaponSpawnMaterial=MaterialInstance'Sentinel_Resources.Materials.Sentinel.MI_Sentinel_Spawn'
	WeaponDeadMaterial=MaterialInstance'Sentinel_Resources.Materials.Sentinel.MI_Sentinel_Dead'
	WeaponScale=0.6

	ActivateSound=SoundCue'Sentinel_Resources.Sounds.Weapons.MOG_ActivateCue'

	AmmoCost=50
	CompatibleSentinels.Remove(class'Sentinel_Ceiling')

	Begin Object Class=SentinelWeaponComponent_FireInfo Name=FireInfo0
		FireInterval=2.3
		ProjectileClass=class'SentinelProjectile_MOG'
		FireOffset=(X=20.0,Y=0.0,Z=0.0)
		FireSound=SoundCue'Sentinel_Resources.Sounds.Weapons.MOG_FireCue'
	End Object
	FireInfo=FireInfo0

	Begin Object Class=SentinelWeaponComponent_MuzzleFlash Name=MuzzleFlash0
		Template=ParticleSystem'Sentinel_Resources.Effects.Weapons.P_MOG_MuzzleFlash'
		MuzzleFlashDuration=0.07
		MuzzleFlashOffset=(X=-20.0,Y=0.0,Z=0.0)
	End Object
	MuzzleFlash=MuzzleFlash0
}
