//=============================================================================
// Default weapon, fires link type projectiles.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class SentinelWeapon_PulseCannon extends SentinelWeapon;

/** Set to Cannon.TeamColour in InitMuzzleFlash. Used for muzzle flash and projectile. */
var LinearColor EffectColour;

simulated function NotifyTeamChanged()
{
	InitMuzzleFlash();
}

simulated function InitMuzzleFlash()
{
	super.InitMuzzleFlash();

	EffectColour = Cannon.TeamColour;

	if(Cannon != none)
	{
		if(MuzzleFlash != none)
		{
			MuzzleFlash.SetColour(EffectColour);
		}

		if(MuzzleFlashLight != none)
		{
			MuzzleFlashLight.SetColour(EffectColour);
		}
	}
}

function bool FireAt(Vector Start, Rotator BarrelDir, Vector End)
{
	local Vector Aim;
	local Vector X, Y, Z;
	local Vector SpawnLocation;
	local Projectile Proj;
	local bool bFired;

	Aim = Normal(Normal(End - Start) + (Normal(VRand()) * FireInfo.Spread));
	GetAxes(BarrelDir, X, Y, Z);

	SpawnLocation = Start;
	SpawnLocation += X * FireInfo.FireOffset.X;
	SpawnLocation += Y * FireInfo.FireOffset.Y;
	SpawnLocation += Z * FireInfo.FireOffset.Z;

	Proj = Cannon.Spawn(FireInfo.ProjectileClass, Cannon,, SpawnLocation, Rotator(Aim));

	if(Proj != none)
	{
		InitializeProjectile(Proj, Aim);
		bFired = super.FireAt(Start, BarrelDir, End);
	}

	return bFired;
}

function InitializeProjectile(Projectile Proj, Vector ProjDir, optional Vector TargetLocation)
{
	local SentinelProjectile_Pulse PulseProj;

	super.InitializeProjectile(Proj, ProjDir, TargetLocation);

	PulseProj = SentinelProjectile_Pulse(Proj);

	if(PulseProj != none)
	{
		PulseProj.SetColour(EffectColour);
	}
}

defaultproperties
{
	FriendlyName="Pulse Cannon"
	Description="The standard weapon fitted to all Sentinels, offering a good balance of power, speed and range. It generates its own power, giving it an effectively unlimited quantity of ammunition."

	WeaponMesh=SkeletalMesh'Sentinel_Resources.Meshes.Weapons.SK_PulseCannon'
	PhysicsAsset=PhysicsAsset'Sentinel_Resources.Physics.SK_PulseCannon_Physics'
	WeaponMaterial=MaterialInstance'Sentinel_Resources.Materials.Sentinel.MI_Sentinel'
	WeaponSpawnMaterial=MaterialInstance'Sentinel_Resources.Materials.Sentinel.MI_Sentinel_Spawn'
	WeaponDeadMaterial=MaterialInstance'Sentinel_Resources.Materials.Sentinel.MI_Sentinel_Dead'
	WeaponScale=0.6

	ActivateSound=SoundCue'Sentinel_Resources.Sounds.Weapons.SwitchToLinkGunCue'

	AmmoCost=20
	CompatibleSentinels.Remove(class'Sentinel_Ceiling')

	Begin Object Class=SentinelWeaponComponent_FireInfo Name=FireInfo0
		FireInterval=0.8
		ProjectileClass=class'SentinelProjectile_Pulse'
		FireOffset=(X=70.0,Y=0.0,Z=1.0)
		FireSound=SoundCue'Sentinel_Resources.Sounds.Weapons.BLinkedFireCue'
	End Object
	FireInfo=FireInfo0

	Begin Object Class=SentinelWeaponComponent_MuzzleFlash Name=MuzzleFlash0
		Template=ParticleSystem'Sentinel_Resources.Effects.Weapons.P_PulseCannon_MuzzleFlash'
		MuzzleFlashDuration=0.15
		MuzzleFlashOffset=(X=10.0,Y=0.0,Z=1.0)
		MuzzleFlashColourName=Colour
	End Object
	MuzzleFlash=MuzzleFlash0

	Begin Object Class=SentinelWeaponComponent_MuzzleFlashLight Name=MuzzleFlashLightComponent0
		LightOffset=(X=30.0,Y=0.0,Z=1.0)
		TimeShift=((StartTime=0.0,Radius=200,Brightness=5,LightColor=(R=200,G=200,B=200,A=255)),(StartTime=0.1,Radius=100,Brightness=5,LightColor=(R=64,G=64,B=64,A=255)),(StartTime=0.15,Radius=64,Brightness=0,LightColor=(R=32,G=32,B=32,A=255)))
	End Object
	MuzzleFlashLight=MuzzleFlashLightComponent0
}
