//=============================================================================
// Attaches to ceilings and shoots at stuff.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class Sentinel_Ceiling extends Sentinel;

var bool bWasBased;

//Suicide if base goes away, e.g. was attached to a vehicles that was destroyed.
function PawnBaseDied()
{
	Suicide();
}

function BaseChange()
{
	super.BaseChange();

	if(Base != none)
	{
		bWasBased = true;
	}
	else if(bWasBased)
	{
		Suicide();
	}
}

defaultproperties
{
	MenuName="Ceiling cannon (light)"
	ShortMenuName="Ceiling cannon"
	IconHudTexture=Texture2D'Sentinel_Resources.Textures.UI.T_Icon_Sentinel_Ceiling'

	DefaultWeaponClass=class'SentinelWeapon_PulseCannon_Small'

	DiedDamage=100
	DiedDamageRadius=120
	DiedMomentum=7000

	MaxRotationSpeed=(Pitch=30000,Yaw=30000)
	RotationDampingThreshold=3072
	AutoRotateRate=4000
	MaxPitch=12288.0
	MinPitch=-4096.0

	AimAhead=0.9
	HearingThreshold=3000.0
	SightRadius=10000.0
	PeripheralVision=-0.8 //143 degree FOV
	BaseEyeHeight=-3.2
	EyeHeight=-3.2

	Health=700

	Mass=200.0
	bCollideWorld=false //So it can spawn where we want, not where the collision says it will fit (will fail to spawn in some locations otherwise).

	Begin Object Name=CollisionCylinder
		CollisionRadius=17.0
		CollisionHeight=16.0
	End Object

	Begin Object Name=BaseComponent0
		SpawnMaterial=MaterialInstance'Sentinel_Resources.Materials.Sentinel.MI_Sentinel_Spawn'
		DeadMaterial=MaterialInstance'Sentinel_Resources.Materials.Sentinel.MI_Sentinel_Dead'
		bCanGib=false
		SkeletalMesh=SkeletalMesh'Sentinel_Resources.Meshes.Sentinel.SK_Base_Ceiling'
		Materials[0]=MaterialInstance'Sentinel_Resources.Materials.Sentinel.MI_Sentinel'
		PhysicsAsset=PhysicsAsset'Sentinel_Resources.Physics.SK_Base_Ceiling_Physics'
		Scale=0.3
		Translation=(X=0.0,Y=0.0,Z=-16.0)
	End Object

	Begin Object Name=RotatorComponent0
		SpawnMaterial=MaterialInstance'Sentinel_Resources.Materials.Sentinel.MI_Sentinel_Spawn'
		DeadMaterial=MaterialInstance'Sentinel_Resources.Materials.Sentinel.MI_Sentinel_Dead'
		DeadExplodeForce=(X=32.0,Y=32.0,Z=32.0)
		DeadExplodeAngular=32.0
		SkeletalMesh=SkeletalMesh'Sentinel_Resources.Meshes.Sentinel.SK_Rotator'
		Materials[0]=MaterialInstance'Sentinel_Resources.Materials.Sentinel.MI_Sentinel'
		PhysicsAsset=PhysicsAsset'Sentinel_Resources.Physics.SK_Rotator_Physics'
		Scale=0.3
		Translation=(X=0.0,Y=0.0,Z=-16.0)
	End Object

	Begin Object Name=WeaponComponent0
		DeadExplodeForce=(X=128.0,Y=128.0,Z=256.0)
		DeadExplodeAngular=128.0
		Translation=(X=0.0,Y=0.0,Z=8.0)
	End Object

	Begin Object Name=RotationSoundComponent0
		RotationSoundPitchScale=7000.0
		RotationSoundVolumeScale=3500.0
		RotationSoundVolumeMax=2.0
	End Object

	Begin Object Name=RotationSoundComponent1
		RotationSoundPitchScale=7000.0
		RotationSoundVolumeScale=3500.0
		RotationSoundVolumeMax=2.0
	End Object

	Begin Object Class=SentinelComponent_ParticleSystem_Damage Name=DamageComponent0
		DamageThreshold=0.4
		Template=ParticleSystem'Sentinel_Resources.Effects.Sentinel.P_DamageEffect_01'
		Scale=0.5
	End Object
	DamageParticleComponents.Add(DamageComponent0)
	Components.Add(DamageComponent0)

	Begin Object Class=SentinelComponent_ParticleSystem_Damage Name=DamageComponent1
		DamageThreshold=0.15
		Template=ParticleSystem'Sentinel_Resources.Effects.Sentinel.P_DamageEffect_02'
		Scale=0.5
	End Object
	DamageParticleComponents.Add(DamageComponent1)
	Components.Add(DamageComponent1)

	Begin Object Name=ExplosionEffectComponent0
		DecalWidth=128.0
		DecalHeight=128.0
	End Object
}