//=============================================================================
// A floating symbol to indicate possible actions for the holder of a Sentinel
// Deployer.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class SymbolStaticMeshComponent extends StaticMeshComponent;

struct SymbolInfo
{
	var() StaticMesh StaticMesh;
	var() LinearColor Colour;
	var() Vector PrePivot;
	var() Rotator Rotation;
	var() float Scale;
};

var() SymbolInfo UnableSymbol;
var() SymbolInfo ArrowSymbol;
var() SymbolInfo UpgradeSymbol;
var() MaterialInstanceConstant SymbolMICTemplate;
var MaterialInstanceConstant SymbolMIC;

simulated function DrawUnableSymbol(Vector SymbolLocation, Rotator SymbolRotation)
{
	PlaceSymbol(UnableSymbol, SymbolLocation, SymbolRotation);
}

simulated function DrawArrowSymbol(Vector SymbolLocation, Rotator SymbolRotation, Vector SurfaceNormal)
{
	local Vector X, Y, Z;

	Z = -SurfaceNormal;
	Y = Normal(Z cross Vector(SymbolRotation));
	X = Y cross Z;

	SetRotation(OrthoRotation(X, Y, Z));

	PlaceSymbol(ArrowSymbol, SymbolLocation, OrthoRotation(X, Y, Z));
}

simulated function DrawUpgradeSymbol(Sentinel S, Rotator SymbolRotation)
{
	local Vector SymbolLocation;

	SymbolLocation = S.Location;
	SymbolLocation -= Vector(SymbolRotation) * S.CylinderComponent.CollisionRadius;
	PlaceSymbol(UpgradeSymbol, SymbolLocation, SymbolRotation);
}

/**
 * Sets the location and rotation of the symbol and also sets its mesh and colour, if not already set.
 *
 * @param	Symbol			the symbol to use
 * @param	SymbolLocation	where to put the symbol
 * @param	SymbolRotation	orientation for the symbol
 */
simulated function PlaceSymbol(SymbolInfo Symbol, Vector SymbolLocation, Rotator SymbolRotation)
{
	local Vector X, Y, Z;

	if(StaticMesh != Symbol.StaticMesh)
	{
		SetStaticMesh(Symbol.StaticMesh);
		SetMaterial(0, SymbolMICTemplate);
		SymbolMIC = CreateAndSetMaterialInstanceConstant(0);
		SymbolMIC.SetVectorParameterValue('Colour', Symbol.Colour);
		SetScale(Symbol.Scale);
	}

	SetRotation(class'SUtils'.static.RotateRelative(SymbolRotation, Symbol.Rotation.Pitch, Symbol.Rotation.Yaw, Symbol.Rotation.Roll));

	GetAxes(Rotation, X, Y, Z);
	SymbolLocation += X * Symbol.PrePivot.X;
	SymbolLocation += Y * Symbol.PrePivot.Y;
	SymbolLocation += Z * Symbol.PrePivot.Z;
	SetTranslation(SymbolLocation);
}

defaultproperties
{
	UnableSymbol=(StaticMesh=StaticMesh'NodeBuddies.3D_Icons.NodeBuddy_Enabled',Colour=(R=3.0,G=0.0,B=0.0),PrePivot=(X=0.0,Y=-19.0,Z=-42.0),Rotation=(Pitch=0,Yaw=16384,Roll=0),Scale=0.6)
	ArrowSymbol=(StaticMesh=StaticMesh'NodeBuddies.NodeBuddy_PerchUp',Colour=(R=3.0,G=1.0,B=0.0),PrePivot=(X=0.0,Y=-18.0,Z=-108.0),Rotation=(Pitch=0,Yaw=0,Roll=0),Scale=0.65)
	UpgradeSymbol=(StaticMesh=StaticMesh'Sentinel_Resources.Meshes.Misc.Cog',Colour=(R=0.5,G=2.0,B=0.5),PrePivot=(X=0.0,Y=0.0,Z=0.0),Rotation=(Pitch=0,Yaw=0,Roll=0),Scale=0.5)
	SymbolMICTemplate=MaterialInstanceConstant'Sentinel_Resources.Materials.Misc.MI_Icon'

	AbsoluteTranslation=true
	AbsoluteRotation=true
	AbsoluteScale=true
	bOnlyOwnerSee=true
	bIgnoreOwnerHidden=true
	CollideActors=false
	BlockActors=false
	BlockZeroExtent=false
	BlockNonZeroExtent=false
	BlockRigidBody=false
	bAcceptsDecals=false
	bAcceptsDecalsDuringGameplay=false
	bUsePrecomputedShadows=false
	CastShadow=false
	bCastDynamicShadow=false
	bAcceptsLights=false
	bAcceptsDynamicLights=false
	bUseAsOccluder=false
}