//=============================================================================
// Superclass of damage types that cause a burning death.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class UTDmgType_Cooked extends UTDamageType
	abstract;

/** Material to apply to pawns killed by this damage type. */
var() Material OverlayMaterial;
/** If true, emitter effects will be spawned in SpawnHitEffect. */
var() bool bUseHitEffects;
/** Effect spawned on a hit. */
var() ParticleSystem HitEffectParticleSystem;

static function DoCustomDamageEffects(UTPawn ThePawn, class<UTDamageType> TheDamageType, const out TraceHitInfo HitInfo, Vector HitLocation)
{
	ThePawn.SetOverlayMaterial(default.OverlayMaterial);
}

static function SpawnHitEffect(Pawn P, float Damage, Vector Momentum, name BoneName, Vector HitLocation)
{
	local UTPawn UTP;

	if(default.bUseHitEffects)
	{
		UTP = UTPawn(P);

		if(UTP != none && !UTP.bGibbed)
		{
			AttachEmitterRandomlyTo(UTP);
		}
	}
}

/**
 * Spawns a ParticleSystemComponent and attaches it to a random bone in the given pawn.
 */
static function AttachEmitterRandomlyTo(UTPawn UTP)
{
	local ParticleSystemComponent PSC;
	local array<name> AllBoneNames;
	local name BoneName;

	PSC = UTP.WorldInfo.MyEmitterPool.SpawnEmitter(default.HitEffectParticleSystem, UTP.Location);

	if(PSC != none)
	{
		UTP.Mesh.GetBoneNames(AllBoneNames);
		BoneName = AllBoneNames[Rand(AllBoneNames.length - 1)];

		PSC.SetAbsolute(false, true, false);
		UTP.Mesh.AttachComponent(PSC, BoneName);
		PSC.SetTranslation(vect(0.0, 0.0, 0.0));
	}
}

defaultproperties
{
	OverlayMaterial=Material'Sentinel_Resources.Materials.Misc.M_Overlay_Burnt'
	bUseHitEffects=true
	HitEffectParticleSystem=ParticleSystem'Sentinel_Resources.Effects.HitEffects.P_HitEffect_Burn'

	DeathString="`o was roasted by `k's Sentinel."
	FemaleSuicide="`o shouldn't have played with fire."
	MaleSuicide="`o shouldn't have played with fire."

	bDontHurtInstigator=true
	VehicleMomentumScaling=1.0
	VehicleDamageScaling=0.8
	NodeDamageScaling=0.5
	KDamageImpulse=0.0
	bNeverGibs=true
	bCausesBlood=false
	bComplainFriendlyFire=false
	bUseDamageBasedDeathEffects=true
}