//=============================================================================
// Exists so that players can throw ammo. Most of the code is copied from
// UTAmmoPickupFactory or its superclasses so that it behaves like a normal
// ammo pickup.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class UTDropped_SentinelAmmo extends UTDroppedItemPickup;

var repnotify class<UTAmmo_SentinelDeployer> AmmoClass;

var	CylinderComponent CylinderComponent;
var() StaticMeshComponent AmmoPickupMesh;

replication
{
	if(Role == ROLE_Authority && bNetInitial)
		AmmoClass;
}

simulated event ReplicatedEvent(name VarName)
{
	if(VarName == 'AmmoClass')
	{
		InitializeFromAmmoClass(AmmoClass);
	}
	else
	{
		super.ReplicatedEvent(VarName);
	}
}

simulated function SetPickupMesh(PrimitiveComponent NewPickupMesh){}

simulated event Landed(vector HitNormal, Actor FloorActor)
{
	super(DroppedPickup).Landed(HitNormal, FloorActor); //Skip superclass version because all it does is move the mesh which is already carefully positioned.
}

/**
 * Sets the ammo pickup class to emulate.
 */
simulated function InitializeFromAmmoClass(class<UTAmmo_SentinelDeployer> NewAmmoClass)
{
	if(NewAmmoClass != none)
	{
		AmmoClass = NewAmmoClass;

		MaxDesireability = AmmoClass.default.MaxDesireability;
		PickupSound = AmmoClass.default.PickupSound;
		CylinderComponent.SetCylinderSize(AmmoClass.default.CylinderComponent.CollisionRadius, AmmoClass.default.CylinderComponent.CollisionHeight);

		AmmoPickupMesh.SetStaticMesh(AmmoClass.default.AmmoPickupMesh.StaticMesh);
		AmmoPickupMesh.SetMaterial(0, AmmoClass.default.AmmoPickupMesh.Materials[0]);
		AmmoPickupMesh.SetScale(AmmoClass.default.AmmoPickupMesh.Scale);
		AmmoPickupMesh.SetTranslation(AmmoClass.default.AmmoPickupMesh.Translation);
	}
}

function GiveTo(Pawn P)
{
	if(UTInventoryManager(P.InvManager) != none)
	{
		UTInventoryManager(P.InvManager).AddAmmoToWeapon(AmmoClass.default.AmmoAmount, AmmoClass.default.TargetWeapon);
	}

	if(PlayerController(P.Controller) != none)
	{
		PlayerController(P.Controller).ReceiveLocalizedMessage(AmmoClass.default.MessageClass,,,, AmmoClass);
	}

	PickedUpBy(P);
}

function PickedUpBy(Pawn P)
{
	P.MakeNoise(0.2);

	super.PickedUpBy(P);
}

auto state Pickup
{
	function bool ValidTouch(Pawn Other)
	{
		local bool bResult;

		if(super.ValidTouch(Other) && UTInventoryManager(Other.InvManager) != none)
		{
			bResult = UTInventoryManager(Other.InvManager).NeedsAmmo(AmmoClass.default.TargetWeapon);
		}

		return bResult;
	}

	function float BotDesireability(Pawn P, Controller C)
	{
		local UTWeapon W;
		local UTBot Bot;
		local float Result;

		Bot = UTBot(C);

		if(Bot != none)
		{
			W = UTWeapon(P.FindInventoryType(AmmoClass.default.TargetWeapon));

			if(W != none)
			{
				Result = W.DesireAmmo(false) * MaxDesireability;
				// increase desireability for the bot's favorite weapon
				if(ClassIsChildOf(AmmoClass.default.TargetWeapon, Bot.FavoriteWeapon))
				{
					Result *= 1.5;
				}
			}
		}

		return Result;
	}

	//TODO: This is never called. Implemented anyway, in case Epic fix it one day.
	function float DetourWeight(Pawn P, float PathWeight)
	{
		local UTWeapon W;
		local float Result;

		W = UTWeapon(P.FindInventoryType(AmmoClass.default.TargetWeapon));

		if(W != none)
		{
			Result = W.DesireAmmo(true) * MaxDesireability / PathWeight;
		}

		return Result;
	}
}

defaultproperties
{
	Begin Object Class=StaticMeshComponent Name=PickupMeshComponent0
		CastShadow=false
		bCastDynamicShadow=false
		bAcceptsLights=true
		bForceDirectLightMap=true
		LightingChannels=(BSP=true,Dynamic=false,Static=true,CompositeDynamic=false)
		CollideActors=false
		BlockActors = false
		BlockZeroExtent=false
		BlockNonZeroExtent=false
		BlockRigidBody=false
		CullDistance=4000
		bUseAsOccluder=false
		LightEnvironment=DroppedPickupLightEnvironment
	End Object
	AmmoPickupMesh=PickupMeshComponent0
	PickupMesh=PickupMeshComponent0
	Components.Add(PickupMeshComponent0)

	CylinderComponent=CollisionCylinder
}