//=============================================================================
// Randomly spawned ammo has to be a DroppedPickup instead of a PickupFactory
// in order to be added to the navigation network.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class UTDropped_SentinelAmmo_Random extends UTDropped_SentinelAmmo;

//Play a respawn sound so it feels more like an ordinary pickup, not a dropped one.
simulated function InitializeFromAmmoClass(class<UTAmmo_SentinelDeployer> NewAmmoClass)
{
	super.InitializeFromAmmoClass(NewAmmoClass);

	if(NewAmmoClass != none)
	{
		PlaySound(NewAmmoClass.default.RespawnSound, true);
	}
}

//Don't destroy immediately, so a replacement pickup can be spawned at an appropriate time.
function PickedUpBy(Pawn P)
{
	PlaySound(PickupSound);

	SetHidden(true);
	SetCollision(false, false);

	LifeSpan = AmmoClass.default.RespawnTime;
	Inventory.Destroy();
	MaxDesireability = 0.0;
	GotoState('Hidden');
}

/**
 * Notification that a replacement pickup can be spawned.
 */
delegate PickupDestroyed(UTDropped_SentinelAmmo_Random DestroyedPickup);

//Must NOT be destroyed on reset, or an infinite loop will occur as the mutator tries to spawn more, which are then reset...
function Reset(){}

function Destroyed()
{
	PickupDestroyed(self);

	super.Destroyed();
}

auto state Pickup
{
	function BeginState(name PreviousStateName)
	{
		SetTimer(8.0 + FRand(), true); //Don't know why this doesn't work if I do it right away, but it also needs to be done at regular intervals in case a different pickup is dropped nearby.

		if(LifeSpan > 0.0)
		{
			SetTimer(LifeSpan - 1.0 - FRand(), false, 'FadeOut');
		}
	}

	function FadeOut()
	{
		GotoState('FadeOut');
	}

	function Timer()
	{
		if(PickupCache == none)
		{
			AddToNavigation();
		}
	}

	function EndState(name NextStateName)
	{
		super.EndState(NextStateName);
		ClearTimer();
		ClearTimer('FadeOut');
	}
}

state Hidden
{
	function float BotDesireability(Pawn P, Controller C)
	{
		return 0.0;
	}

	function float DetourWeight(Pawn Other,float PathWeight)
	{
		return 0.0;
	}
}

defaultproperties
{
	LifeSpan=60.0
}