//=============================================================================
// Spawns ammo from destroyed vehicles.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class UTGameRules_VehicleKillAmmo extends GameRules;

/** Class containing ammo classes to use. */
var() class<UTLRI_Sentinel> LRIClass;
/** Fraction of vehicle's MaxHealth that will be spawned as ammo. */
var() float AmmoMultiplier;

function bool PreventDeath(Pawn Killed, Controller Killer, class<DamageType> damageType, vector HitLocation)
{
	local UTVehicle UTV;
	local float AmmoAmount;
	local Vector AmmoSpawnLocation;

	if(Killed != none && Killer != none)
	{
		UTV = UTVehicle(Killed);

		if(UTV != none && UTV.bHasBeenDriven && !WorldInfo.GRI.OnSameTeam(UTV, Killer))
		{
			AmmoAmount = UTV.HealthMax;
			AmmoAmount *= AmmoMultiplier;
			AmmoSpawnLocation = UTV.Location;
			AmmoSpawnLocation.Z += 1.0 * UTV.GetCollisionHeight();

			while(class'SUtils'.static.SpawnAmmoFor(UTV, AmmoSpawnLocation, 1000.0, AmmoAmount, LRIClass)) //TODO: Calculate speed based on vehicle size?
			{
				continue;
			}
		}
	}

	return super.PreventDeath(Killed, Killer, damageType, HitLocation);
}

defaultproperties
{
	LRIClass=class'UTLRI_Sentinel'
	AmmoMultiplier=0.1
}