//=============================================================================
// Causes damage over time to victims when they have been set on fire.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class UTInv_Cooker extends UTInventory;

/** Temperature at which the victim starts burning. */
var() float FirePoint;
/** Limit on temperature, to avoid excessive cooldown time. */
var() float MaxTemp;
/** Decrease in temperature per second. */
var() float CoolingRate;
/** Damage to inflict per DamageCheckInterval. */
var() float Damage;
/** Type of damage to cause. */
var() class<UTDamageType> DamageType;
/** Rate at which damage is caused. */
var() float DamageCheckInterval;

/** What's for dinner. */
var UTPawn Victim;
/** Current temperature */
var float Temperature;
/** Who will be credited with the damage dealt. */
var Controller Chef;

replication
{
	if(Role == ROLE_Authority && bNetDirty)
		Temperature, Victim;
}

function GivenTo(Pawn thisPawn, optional bool bDoNotActivate)
{
	super.GivenTo(thisPawn, bDoNotActivate);

	Victim = UTPawn(Owner);

	if(Victim == none)
	{
		`warn("Cooker created with no owner:"@Owner);
	}
}

function Cook(float Heat, Controller NewChef)
{
	if(NewChef != none)
	{
		Chef = NewChef;
		Temperature = FMin(Temperature + Heat, MaxTemp);
	}
}

function Tick(float DeltaTime)
{
	super.Tick(DeltaTime);

	Temperature = FMax(Temperature - (CoolingRate * DeltaTime), 0.0);
}

//If owner killed while burning, force overlay to be applied.
simulated function Destroyed()
{
	local TraceHitInfo HitInfo;

	if(Temperature >= FirePoint && DamageType.default.bUseDamageBasedDeathEffects)
	{
		if(Victim != none && Victim.Health <= 0)
		{
			DamageType.static.DoCustomDamageEffects(Victim, class'UTDamageType', HitInfo, Victim.Location);
		}
	}

	super.Destroyed();
}

//Waiting until something hot comes along.
auto state Waiting
{
	function Cook(float Heat, Controller NewChef)
	{
		global.Cook(Heat, NewChef);

		if(Temperature >= FirePoint)
		{
			GotoState('Cooking');
		}
	}
}

//Burning, causing damage.
state Cooking
{
	function BeginState(name PreviousStateName)
	{
		Timer();
		SetTimer(DamageCheckInterval, true);
	}

	function Timer()
	{
		if(Temperature < FirePoint)
		{
			GotoState('Waiting');
		}
		else
		{
			Victim.TakeDamage(Damage, Chef, Victim.Location, vect(0.0, 0.0, 0.0), DamageType);
			Sentinel(Instigator).NotifyCausedDamage(Victim);
		}
	}

	function EndState(name NextStateName)
	{
		ClearTimer();
	}
}

defaultproperties
{
	FirePoint=100.0
	MaxTemp=200.0
	CoolingRate=10.0
	Damage=3.0
	DamageType=class'UTDmgType_Cooked'
	DamageCheckInterval=1.0

	bDropOnDisrupt=false

	bOnlyRelevantToOwner=false
	NetUpdateFrequency=3
}