class UTLocalMessage_DeployerAction extends UTLocalMessage;

enum EDeployerAction
{
	DA_Deploy,
	DA_Upgrade,
	DA_NoUpgrades,
	DA_TooMany,
	DA_TooManyTeam,
	DA_TooManyTeamAdvantage,
	DA_NoAmmo,
	DA_TooCloseToEnemy,
	DA_Failed,
	DA_NoSentinel,
	DA_AlreadyRepaired,
	DA_ConnectionLost
};

var(Message) localized string PressString;
var(Message) localized string DeployString;
var(Message) localized string UpgradeString;
var(Message) localized string UpgradingDisallowedString;
var(Message) localized string TooManySentinelsString;
var(Message) localized string TooManyTeamSentinelsString;
var(Message) localized string TooManyTeamAdvantageSentinelsString;
var(Message) localized string NoAmmoString;
var(Message) localized string TooCloseToEnemyString;
var(Message) localized string FailedString;
var(Message) localized string NoSentinelString;
var(Message) localized string AlreadyRepairedString;
var(Message) localized string ConnectionLostString;

var Color RedColor;

static function string GetString(optional int Switch, optional bool bPRI1HUD, optional PlayerReplicationInfo RelatedPRI_1, optional PlayerReplicationInfo RelatedPRI_2, optional Object OptionalObject)
{
	local String GotString;
	local String AltFireString;

	if(RelatedPRI_1 != none)
	{
		UTPlayerController(RelatedPRI_1.Owner).BoundEventsStringDataStore.GetStringWithFieldName("GBA_AltFire", AltFireString);
	}

	switch(Switch)
	{
		case DA_Deploy:
			GotString = default.PressString@AltFireString@default.DeployString;
			break;
		case DA_Upgrade:
			GotString = default.PressString@AltFireString@default.UpgradeString;
			break;
		case DA_NoUpgrades:
			GotString = default.UpgradingDisallowedString;
			break;
		case DA_TooMany:
			GotString = default.TooManySentinelsString;
			break;
		case DA_TooManyTeam:
			GotString = default.TooManyTeamSentinelsString;
			break;
		case DA_TooManyTeamAdvantage:
			GotString = default.TooManyTeamAdvantageSentinelsString;
			break;
		case DA_NoAmmo:
			GotString = default.NoAmmoString;
			break;
		case DA_TooCloseToEnemy:
			GotString = default.TooCloseToEnemyString;
			break;
		case DA_Failed:
			GotString = default.FailedString;
			break;
		case DA_NoSentinel:
			GotString = default.NoSentinelString;
			break;
		case DA_AlreadyRepaired:
			GotString = default.AlreadyRepairedString;
			break;
		case DA_ConnectionLost:
			GotString = default.ConnectionLostString;
			break;
	}

	return GotString;
}

static function float GetLifeTime(int Switch)
{
	local float GotLifeTime;

	switch(Switch)
	{
		case DA_Deploy:
			GotLifeTime = default.LifeTime;
			break;
		case DA_Upgrade:
			GotLifeTime = default.LifeTime;
			break;
		default:
			GotLifeTime = default.LifeTime * 3.0;
			break;
	}

	return GotLifeTime;
}

static function Color GetColor(optional int Switch, optional PlayerReplicationInfo RelatedPRI_1, optional PlayerReplicationInfo RelatedPRI_2, optional Object OptionalObject)
{
	local Color GotColor;

	switch(Switch)
	{
		case DA_Deploy:
			GotColor = default.DrawColor;
			break;
		case DA_Upgrade:
			GotColor = default.DrawColor;
			break;
		default:
			GotColor = default.RedColor;
			break;
	}

	return GotColor;
}

defaultproperties
{
	PressString="Press"
	DeployString="to deploy here"
	UpgradeString="to upgrade this Sentinel"
	UpgradingDisallowedString="Upgrading disabled"
	TooManySentinelsString="Sentinel limit reached"
	TooManyTeamSentinelsString="Team Sentinel limit reached"
	TooManyTeamAdvantageSentinelsString="Team advantage Sentinel limit reached"
	NoAmmoString="Insufficient ammo"
	TooCloseToEnemyString="Too close to an enemy spawn point"
	FailedString="Failed to deploy at this location"
	NoSentinelString="No Sentinel here to repair or sabotage"
	AlreadyRepairedString="Sentinel fully repaired"
	ConnectionLostString="Connection Lost"

	RedColor=(R=255,G=0,B=0,A=255)

	Lifetime=1.0
	bIsUnique=false
	bIsPartiallyUnique=true
	bBeep=false
	DrawColor=(R=0,G=160,B=255,A=255)
	FontSize=1
	MessageArea=3
	bIsConsoleMessage=false
}
