//=============================================================================
// Constantly refills all Sentinel Deployers.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class UTMutator_DeployerAmmoRegen extends UTMutator
	config(Mutator_Sentinel);

/** Time between additions of ammo. */
var() float RegenInterval;
/** Quantity of ammo to add each time. */
var() config float RegenAmount;

/** Any fractions of an ammo unit left over from the last addition, to be added next time to avoid rounding errors. */
var float RegenCarry;

function MatchStarting()
{
	super.MatchStarting();

	SetTimer(RegenInterval, true, 'RegenAmmo');
}

/**
 * Adds RegenAmount ammo to every Sentinel Deployer held by a player.
 */
function RegenAmmo()
{
	local Controller C;
	local Inventory Deployer;
	local int AmmoToAdd;

	//Calculate the actual amount to add this time, storing any fractions for next time.
	RegenCarry += RegenAmount;
	AmmoToAdd = int(RegenCarry);
	RegenCarry -= AmmoToAdd;

	foreach WorldInfo.AllControllers(class'Controller', C)
	{
		if(C.Pawn != none)
		{
			Deployer = C.Pawn.FindInventoryType(class'UTWeap_SentinelDeployer', true);

			if(Deployer != none)
			{
				Weapon(Deployer).AddAmmo(AmmoToAdd);
			}
		}
	}
}

defaultproperties
{
	RegenInterval=5.0
	RegenAmount=5.0
}