//=============================================================================
// Superclass for all mutators that add Sentinels.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class UTMutator_SentinelBaseMutator extends UTMutator
	abstract;

/** Weapon to give all players when they spawn. Subclasses handle this. */
var() class<Weapon> DeployerClass;

/** Class to spawn for precaching purposes. */
var() class<SentinelPrecachingActor> PrecachingActorClass;
var SentinelPrecachingActor PrecachingActor;

/** Class of objective to spawn to handle drawing Sentinel icons on the map. */
var() class<SentinelDummyObjective> DummyObjectiveClass;
var SentinelDummyObjective DummyObjective;

function InitMutator(string Options, out string ErrorMessage)
{
	super.InitMutator(Options, ErrorMessage);

	LogVersion();

	PrecachingActor = PrecachingActorClass.static.CreatePrecachingActor(WorldInfo);
	DummyObjective = DummyObjectiveClass.static.CreateDummyObjective(WorldInfo);
}

/**
 * Writes version number to the log, just to help debugging when receiving log files but no other information.
 */
function LogVersion()
{
	local DataStoreClient DataStoreManager;
	local UTUIDataStore_MenuItems MenuDataStore;
	local int i;
	local string FriendlyName;

	DataStoreManager = class'UIInteraction'.static.GetDataStoreClient();

	if(DataStoreManager != none)
	{
		MenuDataStore = UTUIDataStore_MenuItems(DataStoreManager.FindDataStore('UTMenuItems'));

		if(MenuDataStore != none)
		{
			i = MenuDataStore.FindValueInProviderSet('Mutators', 'ClassName', PathName(Class));

			if(i != INDEX_NONE)
			{
				MenuDataStore.GetValueFromProviderSet('Mutators', 'FriendlyName', i, FriendlyName);
				`log(FriendlyName);
			}
			else
			{
				`warn("Mutator has no DataProvider");
			}
		}
	}
}

function GetSeamlessTravelActorList(bool bToEntry, out array<Actor> ActorList)
{
	//local Actor A;

	if(PrecachingActor != none)
	{
		`log("Seamless travelling with PrecachingActor:"@PrecachingActor);
		ActorList[ActorList.Length] = PrecachingActor;
	}

	/*`log("GetSeamlessTravelActorList:"@bToEntry);

	foreach ActorList(A)
	{
		`log(A);
	}*/

	super.GetSeamlessTravelActorList(bToEntry, ActorList);
}

defaultproperties
{
	DeployerClass=class'UTWeap_SentinelDeployer'
	PrecachingActorClass=class'SentinelPrecachingActor'
	DummyObjectiveClass=class'SentinelDummyObjective'
}