//=============================================================================
// Holds a list of names of mortar shell types, so they can be displayed in a
// config UI.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class UTUIDataStore_MortarShells extends UTUIDataStore_StringList;

function FillListFrom(array<SentinelWeaponComponent_FireInfo> FireInfos)
{
	local SentinelWeaponComponent_FireInfo FireInfo;
	local class<SentinelProjectile_Mortar> ShellClass;

	Empty('ShellType', true);

	foreach FireInfos(FireInfo)
	{
		ShellClass = class<SentinelProjectile_Mortar>(FireInfo.ProjectileClass);

		AddStr('ShellType', ShellClass.default.FriendlyName,  true);
	}
}

function SentinelWeaponComponent_FireInfo GetFireInfoFromFriendlyName(array<SentinelWeaponComponent_FireInfo> FireInfos, string ShellName)
{
	local SentinelWeaponComponent_FireInfo FireInfo;
	local class<SentinelProjectile_Mortar> ShellClass;

	foreach FireInfos(FireInfo)
	{
		ShellClass = class<SentinelProjectile_Mortar>(FireInfo.ProjectileClass);

		if(ShellClass.default.FriendlyName ~= ShellName)
		{
			return FireInfo;
		}
	}

	return none;
}

function class<SentinelProjectile_Mortar> GetProjectileClassFromFriendlyName(array<SentinelWeaponComponent_FireInfo> FireInfos, string ShellName)
{
	local SentinelWeaponComponent_FireInfo FireInfo;
	local class<SentinelProjectile_Mortar> ShellClass;

	FireInfo = GetFireInfoFromFriendlyName(FireInfos, ShellName);

	if(FireInfo != none)
	{
		ShellClass = class<SentinelProjectile_Mortar>(FireInfo.ProjectileClass);
	}

	return ShellClass;
}

function string GetDescriptionFromFriendlyName(array<SentinelWeaponComponent_FireInfo> FireInfos, string ShellName)
{
	local string ShellDescription;
	local class<SentinelProjectile_Mortar> ShellClass;

	ShellClass = GetProjectileClassFromFriendlyName(FireInfos, ShellName);

	if(ShellClass != none)
	{
		ShellDescription = ShellClass.default.Description;
	}

	return ShellDescription;
}

/**
 * Finds the index into the FireInfos array that contains the projectile with a FriendlyName of ShellName, or INDEX_NONE if not found.
 */
function int GetIndexFromFriendlyName(array<SentinelWeaponComponent_FireInfo> FireInfos, string ShellName)
{
	local int i;
	local class<SentinelProjectile_Mortar> ShellClass;

	for(i = 0; i < FireInfos.length; i++)
	{
		ShellClass = class<SentinelProjectile_Mortar>(FireInfos[i].ProjectileClass);

		if(ShellClass != none)
		{
			if(ShellClass.default.FriendlyName ~= ShellName)
			{
				return i;
			}
		}
	}

	return INDEX_NONE;
}

defaultproperties
{
	Tag=MortarShells
}