//=============================================================================
// Menu for configuring the ammo regen mutator.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class UTUIScene_AmmoRegenMutatorMenu extends UTUIFrontEnd;

var() class<UTMutator_DeployerAmmoRegen> MutatorClass;

var transient UINumericEditBox RegenAmountBox;

function SceneActivated(bool bInitialActivation)
{
	super.SceneActivated(bInitialActivation);

	if(!bInitialActivation)
		return;

	UILabel(FindChild('UILabel_AmmoAmount', true)).SetDataStoreBinding("Regen rate");
	RegenAmountBox = UINumericEditBox(FindChild('RegenAmount', true));
	RegenAmountBox.SetNumericValue(MutatorClass.default.RegenAmount);
}

//Overriden because original only loads from UTGameUI.int
function SetTitle()
{
	local UILabel TitleLabel;
	local UTUIDataStore_MenuItems MenuDataStore;
	local int MutatorIndex;
	local string MutatorName;

	TitleLabel = GetTitleLabel();

	if(TitleLabel != none)
	{
		//Find mutator's FriendlyName.
		MenuDataStore = UTUIDataStore_MenuItems(class'UIInteraction'.static.GetDataStoreClient().FindDataStore('UTMenuItems'));
		MutatorIndex = MenuDataStore.FindValueInProviderSet('Mutators', 'ClassName', PathName(MutatorClass));

		if(MutatorIndex != INDEX_NONE)
		{
			MenuDataStore.GetValueFromProviderSet('Mutators', 'FriendlyName', MutatorIndex, MutatorName);
		}

		TitleLabel.SetDataStoreBinding(MutatorName);
	}
}

function SetupButtonBar()
{
	ButtonBar.Clear();
	ButtonBar.AppendButton("<Strings:UTGameUI.ButtonCallouts.Back>", OnButtonBar_Back);
	ButtonBar.AppendButton("<Strings:UTGameUI.ButtonCallouts.Accept>", OnButtonBar_Accept);
}

function bool OnButtonBar_Back(UIScreenObject InButton, int InPlayerIndex)
{
	CloseScene(self);

	return true;
}

function bool OnButtonBar_Accept(UIScreenObject InButton, int InPlayerIndex)
{
	MutatorClass.default.RegenAmount = RegenAmountBox.GetNumericValue();
	MutatorClass.static.StaticSaveConfig();

	CloseScene(self);

	return true;
}

function bool HandleInputKey(const out InputEventParameters EventParms)
{
	local bool bResult;

	if(EventParms.EventType == IE_Released)
	{
		//Catch ESC press and close menu.
		if(EventParms.InputKeyName == 'Escape')
		{
			bResult = CloseScene(self);
		}
		//Allow screenshots to be taken.
		else if(GetUTPlayerOwner().PlayerInput.GetBind(EventParms.InputKeyName) ~= "shot")
		{
			bResult = true;
			ConsoleCommand("shot");
		}
	}

	return bResult;
}

defaultproperties
{
	OnRawInputKey=HandleInputKey

	MutatorClass=class'UTMutator_DeployerAmmoRegen'
}