//=============================================================================
// Menu for configuring the Nightshade mutator.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class UTUIScene_NightshadeMutatorMenu extends UTUIFrontEnd;

var() class<UTMutator_NightshadeSentinel> MutatorClass;

var transient UINumericEditBox DeployableIndex;
var transient UILabel DeployableName;

function SceneActivated(bool bInitialActivation)
{
	super.SceneActivated(bInitialActivation);

	if(!bInitialActivation)
		return;

	UILabel(FindChild('UILabel_DeployableIndex', true)).SetDataStoreBinding("Deployable To Replace With Sentinels");
	DeployableIndex = UINumericEditBox(FindChild('UTUINumericEditBox_DeployableIndex', true));
	DeployableIndex.NumericValue.MaxValue = ArrayCount(class'UTVWeap_NightshadeGun_Content'.default.DeployableList) - 1;
	DeployableIndex.SetNumericValue(MutatorClass.default.ReplacedDeployableIndex);

	DeployableName = UILabel(FindChild('UILabel_DeployableName', true));
	DeployableName.SetDataStoreBinding(class'UTVWeap_NightshadeGun_Content'.default.DeployableList[MutatorClass.default.ReplacedDeployableIndex].DeployableClass.default.ItemName);
}

//Overriden because original only loads from UTGameUI.int
function SetTitle()
{
	local UILabel TitleLabel;
	local UTUIDataStore_MenuItems MenuDataStore;
	local int MutatorIndex;
	local string MutatorName;

	TitleLabel = GetTitleLabel();

	if(TitleLabel != none)
	{
		//Find mutator's FriendlyName.
		MenuDataStore = UTUIDataStore_MenuItems(class'UIInteraction'.static.GetDataStoreClient().FindDataStore('UTMenuItems'));
		MutatorIndex = MenuDataStore.FindValueInProviderSet('Mutators', 'ClassName', PathName(MutatorClass));

		if(MutatorIndex != INDEX_NONE)
		{
			MenuDataStore.GetValueFromProviderSet('Mutators', 'FriendlyName', MutatorIndex, MutatorName);
		}

		TitleLabel.SetDataStoreBinding(MutatorName);
	}
}

function SetupButtonBar()
{
	ButtonBar.Clear();
	ButtonBar.AppendButton("<Strings:UTGameUI.ButtonCallouts.Back>", OnButtonBar_Back);
	ButtonBar.AppendButton("<Strings:UTGameUI.ButtonCallouts.Accept>", OnButtonBar_Accept);
}

function bool OnButtonBar_Back(UIScreenObject InButton, int InPlayerIndex)
{
	CloseScene(self);

	return true;
}

function bool OnButtonBar_Accept(UIScreenObject InButton, int InPlayerIndex)
{
	MutatorClass.default.ReplacedDeployableIndex = DeployableIndex.GetNumericValue();
	MutatorClass.static.StaticSaveConfig();

	CloseScene(self);

	return true;
}

function bool HandleInputKey(const out InputEventParameters EventParms)
{
	local bool bResult;

	if(EventParms.EventType == IE_Released)
	{
		//Catch ESC press and close menu.
		if(EventParms.InputKeyName == 'Escape')
		{
			bResult = CloseScene(self);
		}
		//Allow screenshots to be taken.
		else if(GetUTPlayerOwner().PlayerInput.GetBind(EventParms.InputKeyName) ~= "shot")
		{
			bResult = true;
			ConsoleCommand("shot");
		}
	}

	return bResult;
}

defaultproperties
{
	OnRawInputKey=HandleInputKey

	MutatorClass=class'UTMutator_NightshadeSentinel'
}