//=============================================================================
// Configuration for the "Scan Angle Limiter" upgrade.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class UTUIScene_ScanAngleLimiterMenu extends UTUIScene_UpgradeConfigurationMenu;

var transient UTUISlider AutoRotateRangeSlider;
var transient UTUISlider AutoRotateCentreSlider;

var transient UTUIButtonBar ButtonBar;
var transient UTUIButtonBarButton ApplyButton;
var transient UTUIButtonBarButton CancelButton;

function SceneActivated(bool bInitialActivation)
{
	local int ButtonIndex;

	super.SceneActivated(bInitialActivation);

	if(bInitialActivation)
	{
		UILabel(FindChild('UILabel_Title', true)).SetValue(class'SentinelUpgrade_ScanAngleLimiter'.default.FriendlyName);

		//Sliders
		UILabel(FindChild('UILabel_AutoRotateRange', true)).SetValue(class'SentinelUpgrade_ScanAngleLimiter'.default.ScanAngleRange);
		AutoRotateRangeSlider = UTUISlider(FindChild('UTUISlider_AutoRotateRange', true));
		SetRangeData(AutoRotateRangeSlider, 0.0, 360.0, 0.0, 5.0, true);

		UILabel(FindChild('UILabel_AutoRotateCentre', true)).SetValue(class'SentinelUpgrade_ScanAngleLimiter'.default.ScanAngleCentre);
		AutoRotateCentreSlider = UTUISlider(FindChild('UTUISlider_AutoRotateCentre', true));
		SetRangeData(AutoRotateCentreSlider, -180.0, 180.0, 0.0, 5.0, true);

		//Button bar
		ButtonBar = UTUIButtonBar(FindChild('UTUIButtonBar_0', true));
		ButtonBar.Clear();

		ButtonIndex = ButtonBar.AppendButton("<Strings:UTGameUI.ButtonCallouts.Apply>", OnButtonBar_Apply);
		ApplyButton = ButtonBar.Buttons[ButtonIndex];

		ButtonIndex = ButtonBar.AppendButton("<Strings:UTGameUI.ButtonCallouts.Cancel>", OnButtonBar_Cancel);
		CancelButton = ButtonBar.Buttons[ButtonIndex];
		CancelButton.SetDockParameters(UIFACE_Left, ButtonBar, UIFACE_Left, 0);
		CancelButton.SetDockParameters(UIFACE_Right, none, UIFACE_MAX, 0);
	}
}

function InitializeFor(SentinelUpgrade NewUpgrade)
{
	super.InitializeFor(NewUpgrade);

	if(Upgrade != none && Upgrade.Cannon != none)
	{
		AutoRotateRangeSlider.SetValue((Upgrade.Cannon.AutoRotateHalfRange / 32768.0) * 360.0);
		AutoRotateRangeSlider.NotifyValueChanged();

		AutoRotateCentreSlider.SetValue((Upgrade.Cannon.AutoRotateCentre / 65536.0) * 360.0);
		AutoRotateCentreSlider.NotifyValueChanged();
	}
}

function float GetAutoRotateRange()
{
	return (AutoRotateRangeSlider.GetValue() / 360.0) * 65536.0;
}

function float GetAutoRotateCentre()
{
	return (AutoRotateCentreSlider.GetValue() / 360.0) * 65536.0;
}

static function SetRangeData(UISlider Slider, float MinValue, float MaxValue, float CurrentValue, float NudgeValue, bool bIntRange)
{
	Slider.SliderValue.MinValue = MinValue;
	Slider.SliderValue.MaxValue = MaxValue;
	Slider.SliderValue.CurrentValue = CurrentValue;
	Slider.SliderValue.NudgeValue = NudgeValue;
	Slider.SliderValue.bIntRange = bIntRange;

	Slider.NotifyValueChanged();
}

function bool OnButtonBar_Apply(UIScreenObject InButton, int InPlayerIndex)
{
	if(Upgrade != none)
	{
		SentinelUpgrade_ScanAngleLimiter(Upgrade).SetAutoRotateParams(GetAutoRotateRange(), GetAutoRotateCentre());
	}

	CloseScene(self);

	return true;
}

function bool OnButtonBar_Cancel(UIScreenObject InButton, int InPlayerIndex)
{
	CloseScene(self);

	return true;
}

defaultproperties
{
}