//=============================================================================
// Menu for configuring the main mutator. Most actual configuration is handled
// by the individual tab pages.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class UTUIScene_SentinelMutatorMenu extends UTUIFrontEnd;

var() class<UTMutator_Sentinel> MutatorClass;

var transient UTUITabPage_SentinelOptions MainTab;
var transient UTUITabPage_SentinelOptions RandomAmmoTab;
var transient UTUITabPage_SentinelOptions AmmoReplacementTab;
var transient UTUITabPage_SentinelOptions AdvancedTab;

function SceneActivated(bool bInitialActivation)
{
	super.SceneActivated(bInitialActivation);

	if(!bInitialActivation)
		return;

	MainTab = UTUITabPage_SentinelOptions(FindChild('TabPage_Main', true));
	RandomAmmoTab = UTUITabPage_SentinelOptions(FindChild('TabPage_Ammo', true));
	AmmoReplacementTab = UTUITabPage_SentinelOptions(FindChild('TabPage_AmmoReplacement', true));
	AdvancedTab = UTUITabPage_SentinelOptions(FindChild('TabPage_Advanced', true));
}

//Overriden because original only loads from UTGameUI.int and won't show the title if there is a tab bar.
function SetTitle()
{
	local UILabel TitleLabel;
	local UTUIDataStore_MenuItems MenuDataStore;
	local int MutatorIndex;
	local string MutatorName;

	TitleLabel = GetTitleLabel();

	if(TitleLabel != none)
	{
		//Find mutator's FriendlyName.
		MenuDataStore = UTUIDataStore_MenuItems(class'UIInteraction'.static.GetDataStoreClient().FindDataStore('UTMenuItems'));
		MutatorIndex = MenuDataStore.FindValueInProviderSet('Mutators', 'ClassName', PathName(MutatorClass));

		if(MutatorIndex != INDEX_NONE)
		{
			MenuDataStore.GetValueFromProviderSet('Mutators', 'FriendlyName', MutatorIndex, MutatorName);
		}

		TitleLabel.SetDataStoreBinding(MutatorName);
	}
}

function SetupButtonBar()
{
	ButtonBar.Clear();
	ButtonBar.AppendButton("<Strings:UTGameUI.ButtonCallouts.Back>", OnButtonBar_Back);
	ButtonBar.AppendButton("<Strings:UTGameUI.ButtonCallouts.Accept>", OnButtonBar_Accept);
}

function bool OnButtonBar_Back(UIScreenObject InButton, int InPlayerIndex)
{
	CloseScene(self);

	return true;
}

function bool OnButtonBar_Accept(UIScreenObject InButton, int InPlayerIndex)
{
	MainTab.Commit();
	RandomAmmoTab.Commit();
	AmmoReplacementTab.Commit();
	AdvancedTab.Commit();

	CloseScene(self);

	return true;
}

function bool HandleInputKey(const out InputEventParameters EventParms)
{
	local bool bResult;

	if(EventParms.EventType == IE_Released)
	{
		//Catch ESC press and close menu.
		if(EventParms.InputKeyName == 'Escape')
		{
			bResult = CloseScene(self);
		}
		//Allow screenshots to be taken.
		else if(GetUTPlayerOwner().PlayerInput.GetBind(EventParms.InputKeyName) ~= "shot")
		{
			bResult = true;
			ConsoleCommand("shot");
		}
	}

	return bResult;
}

defaultproperties
{
	OnRawInputKey=HandleInputKey

	MutatorClass=class'UTMutator_Sentinel'
}