//=============================================================================
// Menu brought up by Deployer for upgrading Sentinels.
// Note that after being initialized, the menu never updates itself, so if
// the Sentinel changes, something external must call RefreshAll() to keep it
// synchronized.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class UTUIScene_SentinelUpgradeMenu extends UTUIScene_SentinelMenu;

/** Sentinel Deployer held by the player that opened this menu. */
var transient UTWeap_SentinelDeployer Deployer;
/** Sentinel this menu is for. */
var transient Sentinel Cannon;
/** Set to true if Cannon belongs to the player this menu is open for. */
var transient bool bOwnSentinel;

var transient UIList AvailableWeaponsList;
var transient UIList CurrentWeaponsList;
var transient UIList AvailableUpgradesList;
var transient UIList CurrentUpgradesList;

var transient UILabel DescriptionLabel;
var transient UILabel AmmoLabel;
var transient UILabel StatusLabel;

var transient UTUIButtonBar ButtonBar_Upper;
var transient UTUIButtonBarButton RecycleButton;
var transient UTUIButtonBarButton CloseButton;

var transient UTUIButtonBar ButtonBar_Lower;
var transient UTUIButtonBarButton ApplyButton;
var transient UTUIButtonBarButton LockButton;
var transient UTUIButtonBarButton ConfigureButton;


/** Set to true once all controls have been initialized in SceneActivated. */
var transient bool bDoneInitialActivation;
/** Stores whether the player's HUD was enabled when they opened this menu, so it can be reset to the original state later. */
var transient bool bOldShowHUD;
/** Used to store which upgrades were applied last time the lists were refreshed. */
var transient array< class<SentinelUpgrade> > LastAppliedUpgradeClasses;

/** DataStore holding upgrade info. */
var transient UTUIDataStore_SentinelUpgrades UpgradeDataStore;
/** Upgrade to apply if apply button pressed. */
var transient class<SentinelUpgrade> SelectedUpgrade;

function SceneActivated(bool bInitialActivation)
{
	local UTPlayerController UTPC;
	local int ButtonIndex;
	local float ButtonWidth;

	super.SceneActivated(bInitialActivation);

	if(bInitialActivation)
	{
		UTPC = GetUTPlayerOwner();

		if(UTPC != none && UTPC.myHUD != none)
		{
			bOldShowHUD = UTPC.myHUD.bShowHUD;
			UTPC.myHUD.bShowHUD = false;
		}

		UILabel(FindChild('UILabel_Title', true)).SetValue(class'UIStrings'.default.MenuTitle);
		UILabel(FindChild('UILabel_AvailableWeapons', true)).SetValue(class'UIStrings'.default.AvailableWeapons);
		UILabel(FindChild('UILabel_CurrentWeapons', true)).SetValue(class'UIStrings'.default.CurrentWeapon);
		UILabel(FindChild('UILabel_AvailableUpgrades', true)).SetValue(class'UIStrings'.default.AvailableUpgrades);
		UILabel(FindChild('UILabel_CurrentUpgrades', true)).SetValue(class'UIStrings'.default.CurrentUpgrades);
		UILabel(FindChild('UILabel_DescriptionLabel', true)).SetValue(class'UIStrings'.default.Description);
		UILabel(FindChild('UILabel_AmmoLabel', true)).SetValue(class'UIStrings'.default.AvailableComponents);
		UILabel(FindChild('UILabel_StatusLabel', true)).SetValue(class'UIStrings'.default.Status);

		AvailableWeaponsList = UIList(FindChild('UIList_AvailableWeapons', true));
		CurrentWeaponsList = UIList(FindChild('UIList_CurrentWeapons', true));
		AvailableUpgradesList = UIList(FindChild('UIList_AvailableUpgrades', true));
		CurrentUpgradesList = UIList(FindChild('UIList_CurrentUpgrades', true));

		AvailableWeaponsList.OnValueChanged = OnAvailableWeaponsChanged;
		AvailableWeaponsList.OnDoubleClick = OnList_DoubleClick;
		CurrentWeaponsList.OnValueChanged = OnCurrentWeaponsChanged;
		AvailableUpgradesList.OnValueChanged = OnAvailableUpgradesChanged;
		AvailableUpgradesList.OnDoubleClick = OnList_DoubleClick;
		CurrentUpgradesList.OnValueChanged = OnCurrentUpgradesChanged;

		AvailableWeaponsList.OnSubmitSelection = OnAvailableList_SubmitSelection;
		CurrentWeaponsList.OnSubmitSelection = OnCurrentList_SubmitSelection;
		AvailableUpgradesList.OnSubmitSelection = OnAvailableList_SubmitSelection;
		CurrentUpgradesList.OnSubmitSelection = OnCurrentList_SubmitSelection;

		DescriptionLabel = UILabel(FindChild('UILabel_Description', true));
		AmmoLabel = UILabel(FindChild('UILabel_Ammo', true));
		StatusLabel = UILabel(FindChild('UILabel_Status', true));

		//Upper button bar (RECYCLE and CLOSE buttons).
		ButtonBar_Upper = UTUIButtonBar(FindChild('UTUIButtonBar_Upper', true));
		ButtonBar_Upper.Clear();

		ButtonIndex = ButtonBar_Upper.AppendButton("<Strings:UTGameUI.ButtonCallouts.Close>", OnButtonBar_Close);
		CloseButton = ButtonBar_Upper.Buttons[ButtonIndex];

		ButtonIndex = ButtonBar_Upper.AppendButton(class'UIStrings'.default.Recycle, OnButtonBar_Recycle);
		RecycleButton = ButtonBar_Upper.Buttons[ButtonIndex];
		RecycleButton.SetDockParameters(UIFACE_Left, ButtonBar_Upper, UIFACE_Left, 0);
		RecycleButton.SetDockParameters(UIFACE_Right, none, UIFACE_MAX, 0);

		//Lower button bar (APPLY, LOCK and CONFIGURE buttons).
		ButtonBar_Lower = UTUIButtonBar(FindChild('UTUIButtonBar_Lower', true));
		ButtonBar_Lower.Clear();

		ButtonIndex = ButtonBar_Lower.AppendButton(class'UIStrings'.default.Configure, OnButtonBar_Configure);
		ConfigureButton = ButtonBar_Lower.Buttons[ButtonIndex];

		ButtonIndex = ButtonBar_Lower.AppendButton("<Strings:UTGameUI.ButtonCallouts.Apply>", OnButtonBar_Apply);
		ApplyButton = ButtonBar_Lower.Buttons[ButtonIndex];
		ApplyButton.SetDockParameters(UIFACE_Left, ButtonBar_Lower, UIFACE_Left, 0);
		ApplyButton.SetDockParameters(UIFACE_Right, none, UIFACE_MAX, 0);

		ButtonIndex = ButtonBar_Lower.AppendButton(class'UIStrings'.default.Lock, OnButtonBar_Lock);
		LockButton = ButtonBar_Lower.Buttons[ButtonIndex];
		LockButton.SetDockParameters(UIFACE_Left, none, UIFACE_MAX, 0);
		LockButton.SetDockParameters(UIFACE_Right, none, UIFACE_MAX, 0);
		ButtonWidth = LockButton.GetPosition(UIFACE_Right, EVALPOS_PercentageScene);
		LockButton.SetPosition(0.5 - (0.5 * ButtonWidth), UIFACE_Left, EVALPOS_PercentageScene, false);

		SetNavTargets();

		bDoneInitialActivation = true;
	}
}

/**
 * Sets navigation between controls with the cursor keys.
 * @todo	This doesn't work, or at least not quite entirely.
 */
function SetNavTargets()
{
	RecycleButton.SetNavigationTarget(UIFace_Right, CloseButton);
	RecycleButton.SetNavigationTarget(UIFace_Bottom, AvailableWeaponsList);
	CloseButton.SetNavigationTarget(UIFace_Left, RecycleButton);
	CloseButton.SetNavigationTarget(UIFace_Bottom, CurrentWeaponsList);

	AvailableWeaponsList.SetNavigationTarget(UIFace_Top, RecycleButton);
	AvailableWeaponsList.SetNavigationTarget(UIFace_Right, CurrentWeaponsList);
	AvailableWeaponsList.SetNavigationTarget(UIFace_Bottom, AvailableUpgradesList);
	CurrentWeaponsList.SetNavigationTarget(UIFace_Top, CloseButton);
	CurrentWeaponsList.SetNavigationTarget(UIFace_Left, AvailableWeaponsList);
	CurrentWeaponsList.SetNavigationTarget(UIFace_Bottom, CurrentUpgradesList);
	AvailableUpgradesList.SetNavigationTarget(UIFace_Top, AvailableWeaponsList);
	AvailableUpgradesList.SetNavigationTarget(UIFace_Right, CurrentUpgradesList);
	AvailableUpgradesList.SetNavigationTarget(UIFace_Bottom, ApplyButton);
	CurrentUpgradesList.SetNavigationTarget(UIFace_Top, CurrentWeaponsList);
	CurrentUpgradesList.SetNavigationTarget(UIFace_Left, AvailableUpgradesList);
	CurrentUpgradesList.SetNavigationTarget(UIFace_Bottom, ConfigureButton);

	ApplyButton.SetNavigationTarget(UIFace_Top, AvailableUpgradesList);
	ApplyButton.SetNavigationTarget(UIFace_Right, LockButton);
	LockButton.SetNavigationTarget(UIFace_Top, none);
	LockButton.SetNavigationTarget(UIFace_Left, ApplyButton);
	LockButton.SetNavigationTarget(UIFace_Right, ConfigureButton);
	ConfigureButton.SetNavigationTarget(UIFace_Top, CurrentUpgradesList);
	ConfigureButton.SetNavigationTarget(UIFace_Left, LockButton);
}

function CentreMouse()
{
	local GameUISceneClient GameSceneClient;
	local Vector DesiredMouseLocation;

	GameSceneClient = GetSceneClient();

	if(GameSceneClient != none)
	{
		//TODO: Want to centre cursor when menu opens, but can't seem to find a place to access current resolution or scene position in pixels.
		//The best I can do for now is to put the cursor over the Sentinel, which should always be near the centre when the menu is first opened.
		ViewportProject(PlayerOwner, Cannon.Location, DesiredMouseLocation);
		GameSceneClient.SetMousePosition(DesiredMouseLocation.X, DesiredMouseLocation.Y);
	}
}

/**
 * Creates UpgradeDataStore and binds the upgrade lists to it.
 */
function InitializeListDataStore()
{
	local DataStoreClient DSClient;

	DSClient = class'UIInteraction'.static.GetDataStoreClient();

	if(DSClient != none)
	{
		UpgradeDataStore = UTUIDataStore_SentinelUpgrades(FindDataStore(Cannon.UpgradeManager.default.UpgradeDataStoreClass.default.Tag));

		if(UpgradeDataStore == none)
		{
			UpgradeDataStore = DSClient.CreateDataStore(Cannon.UpgradeManager.default.UpgradeDataStoreClass);

			if(UpgradeDataStore != none)
				DSClient.RegisterDataStore(UpgradeDataStore);
		}
	}
}

/**
 * Sets up menu for a particular Sentinel.
 *
 * @param	NewDeployer		SentinelDeployer which opened this menu
 * @param	NewSentinel		Sentinel this menu should be configured for
 */
function InitializeFor(UTWeap_SentinelDeployer NewDeployer, Sentinel NewSentinel)
{
	if(NewDeployer == none || NewSentinel == none || NewSentinel.UpgradeManager == none)
	{
		`warn("Failed to initialize upgrade menu:"@NewDeployer@NewSentinel);
		CloseScene(self);

		return;
	}

	Deployer = NewDeployer;
	Cannon = NewSentinel;
	bOwnSentinel = Cannon.InstigatorController != none && Cannon.InstigatorController == GetUTPlayerOwner();

	RecycleButton.SetVisibility(bOwnSentinel);
	LockButton.SetVisibility(bOwnSentinel);
	LockButton.SetDatastoreBinding(Cannon.bTeamUpgradeable ? class'UIStrings'.default.Lock : class'UIStrings'.default.Unlock);
	ConfigureButton.SetVisibility(bOwnSentinel);

	InitializeListDataStore();
	RefreshAll(true);
	CentreMouse();
}

/**
 * Updates contents of all controls that might be out of date.
 *
 * @param	bForceRefresh	a value of true forces all controls to be refreshed unconditionally
 */
function RefreshAll(optional bool bForceRefresh)
{
	if(Cannon.UpgradeManager != none)
	{
		if(UpgradesHaveChanged() || bForceRefresh)
		{
			RefreshLists();
		}
	}

	RefreshStatus();
	RefreshAmmo();
}

/**
 * Checks to see if upgrades applied at last check are different from the ones applied now, and updates LastAppliedUpgradeClasses to match currently applied upgrades.
 */
function bool UpgradesHaveChanged()
{
	local array< class<SentinelUpgrade> > AppliedUpgradeClasses;
	local class<SentinelUpgrade> AppliedUpgradeClass;
	local bool bChanged;

	AppliedUpgradeClasses = Cannon.UpgradeManager.GetAppliedUpgradeClasses();

	if(LastAppliedUpgradeClasses.length != AppliedUpgradeClasses.length)
	{
		bChanged = true;
	}
	else
	{
		foreach AppliedUpgradeClasses(AppliedUpgradeClass)
		{
			if(LastAppliedUpgradeClasses.Find(AppliedUpgradeClass) == INDEX_NONE)
			{
				bChanged = true;
				break;
			}
		}
	}

	LastAppliedUpgradeClasses = AppliedUpgradeClasses;

	return bChanged;
}

/**
 * Reload contents of upgrade lists.
 */
function RefreshLists()
{
	if(Cannon.UpgradeManager != none)
	{
		OnListsChanged(AvailableWeaponsList, CurrentWeaponsList, 'Weapons');
		OnListsChanged(AvailableUpgradesList, CurrentUpgradesList, 'Upgrades');
	}

	SelectionFix(AvailableWeaponsList);
	SelectionFix(CurrentWeaponsList);
	SelectionFix(AvailableUpgradesList);
	SelectionFix(CurrentUpgradesList);
}

/**
 * Fixes bug where upon reopening the menu, a previously selected item would be highlighted, but not actually selected.
 * This ensures that all items in the list are unselected and unhighlighted.
 */
function SelectionFix(UIList ListToFix)
{
	local int i;

	for(i = 0; i < ListToFix.GetItemCount(); i++)
	{
		ListToFix.SetIndex(i,, true);
	}

	ListToFix.SetIndex(-1, false);
}

/**
 * Reloads status text.
 */
function RefreshStatus()
{
	StatusLabel.SetArrayValue(Cannon.GetStatusText());
}

/**
 * Reloads ammo-count text.
 */
function RefreshAmmo()
{
	local String AmmoString;

	if(Deployer != none)
	{
		AmmoString $= class'SUtils'.static.RedGreenTextColourMarkup(Deployer.AmmoCount, Deployer.MaxAmmoCount);
		AmmoString $= Deployer.AmmoCount;
	}
	else
	{
		AmmoString $= class'SUtils'.static.TextColourMarkup(1.0, 0.0, 0.0);
		AmmoString $= "0";
	}

	AmmoLabel.SetValue(AmmoString);
}

/**
 * Deselects lists other than the one the user just clicked on. Having only one list with a highlighted item makes things less ambiguous.
 */
function OnAvailableWeaponsChanged(UIObject Sender, int PlayerIndex)
{
	if(!bDoneInitialActivation)
		return;

	SelectedUpgrade = SetDescriptionFromList(AvailableWeaponsList, 'Weapons');

	ApplyButton.SetEnabled(SelectedUpgrade != none);
	ConfigureButton.SetEnabled(false);
	CurrentWeaponsList.SetIndex(-1, false, true);
	AvailableUpgradesList.SetIndex(-1, false, true);
	CurrentUpgradesList.SetIndex(-1, false, true);
}

function OnCurrentWeaponsChanged(UIObject Sender, int PlayerIndex)
{
	if(!bDoneInitialActivation)
		return;

	SelectedUpgrade = SetDescriptionFromList(CurrentWeaponsList, 'Weapons');

	ApplyButton.SetEnabled(false);
	ConfigureButton.SetEnabled(SelectedUpgrade != none && SelectedUpgrade.default.ConfigurationMenuTemplate != none); 
	AvailableWeaponsList.SetIndex(-1, false, true);
	AvailableUpgradesList.SetIndex(-1, false, true);
	CurrentUpgradesList.SetIndex(-1, false, true);
}

function OnAvailableUpgradesChanged(UIObject Sender, int PlayerIndex)
{
	if(!bDoneInitialActivation)
		return;

	SelectedUpgrade = SetDescriptionFromList(AvailableUpgradesList, 'Upgrades');

	ApplyButton.SetEnabled(SelectedUpgrade != none);
	ConfigureButton.SetEnabled(false); 
	AvailableWeaponsList.SetIndex(-1, false, true);
	CurrentWeaponsList.SetIndex(-1, false, true);
	CurrentUpgradesList.SetIndex(-1, false, true);
}

function OnCurrentUpgradesChanged(UIObject Sender, int PlayerIndex)
{
	if(!bDoneInitialActivation)
		return;

	SelectedUpgrade = SetDescriptionFromList(CurrentUpgradesList, 'Upgrades');

	ApplyButton.SetEnabled(false);
	ConfigureButton.SetEnabled(SelectedUpgrade != none && SelectedUpgrade.default.ConfigurationMenuTemplate != none); 
	AvailableWeaponsList.SetIndex(-1, false, true);
	CurrentWeaponsList.SetIndex(-1, false, true);
	AvailableUpgradesList.SetIndex(-1, false, true);
}

/**
 * Fills description label from selected item of a list.
 *
 * @param	SelectedList	the list that holds the selected item
 * @param	FieldName		tag for this type of upgrade e.g. 'Weapons' or 'Upgrades'
 * @return	the class of the selected item
 */
function class<SentinelUpgrade> SetDescriptionFromList(UIList SelectedList, name FieldName)
{
	local int i;
	local class<SentinelUpgrade> NewClass;
	local string NewDescription;

	i = SelectedList.GetCurrentItem();

	if(i >= 0)
	{
		NewClass = GetClassFromIndex(i, FieldName);

		if(NewClass != none)
		{
			NewDescription = NewClass.default.FriendlyName;
			NewDescription $= "\n\n"$class'UIStrings'.default.Cost$": ";

			if(Deployer == none || Deployer.AmmoCount < NewClass.default.AmmoCost)
				NewDescription $= class'SUtils'.static.TextColourMarkup(1.0, 0.0, 0.0);
			else if(Deployer.AmmoCount == NewClass.default.AmmoCost)
				NewDescription $= class'SUtils'.static.TextColourMarkup(1.0, 1.0, 0.0);
			else
				NewDescription $= class'SUtils'.static.TextColourMarkup(0.0, 1.0, 0.0);

			NewDescription $= NewClass.default.AmmoCost;
			NewDescription $= class'SUtils'.static.TextColourMarkup(1.0, 1.0, 1.0);
			NewDescription $= "\n\n"$NewClass.default.Description;
		}
		else
		{
			NewDescription = class'UIStrings'.default.InvalidUpgrade;
		}
	}
	else
	{
		NewDescription = class'UIStrings'.default.NoUpgrade;
	}

	DescriptionLabel.SetValue(NewDescription);
	//Scroll back up to the top when changing description contents.
	UIScrollFrame(DescriptionLabel.GetOwner()).SetClientRegionPosition(UIORIENT_Vertical, UIScrollFrame(DescriptionLabel.GetOwner()).GetPosition(UIFACE_Top, EVALPOS_PixelViewport));

	return NewClass;
}

/**
 * Ensures the two passed lists contain only the correct items.
 *
 * @param	AvailableList	list that should contain upgrades that the Sentinel could be given
 * @param	CurrentList		list that should contain upgrades that the Sentinel already has
 * @param	FieldName		tag for this type of upgrade e.g. 'Weapons' or 'Upgrades'
 */
function OnListsChanged(UIList AvailableList, UIList CurrentList, name FieldName)
{
	local int i;
	local class<SentinelUpgrade> UpgradeClass;

	AvailableList.IncrementAllMutexes();
	CurrentList.IncrementAllMutexes();

	//First, fill both lists with everything, so they are identical.
	AvailableList.RefreshSubscriberValue();
	CurrentList.RefreshSubscriberValue();

	//Then trim each list of unwanted items.
	for(i = AvailableList.GetItemCount() - 1; i >= 0 ; i--)
	{
		UpgradeClass = GetClassFromIndex(AvailableList.Items[i], FieldName);

		if(!Cannon.UpgradeManager.AllowUpgrade(UpgradeClass))
		{
			//Sentinel not allowed to be upgraded with this, remove it from list of available upgrades.
			AvailableList.RemoveElement(i);
		}

		if(!Cannon.UpgradeManager.HasUpgrade(UpgradeClass))
		{
			//Sentinel doesn't have this upgrade yet, remove it from list of Sentinel's current upgrades.
			CurrentList.RemoveElement(i);
		}
	}

	AvailableList.DecrementAllMutexes();
	CurrentList.DecrementAllMutexes();

	AvailableList.SetIndex(-1);
	CurrentList.SetIndex(-1);
	AvailableList.SetTopIndex(0);
	CurrentList.SetTopIndex(0);

	RequestFormattingUpdate();
	RequestSceneUpdate(false, true);
}

/**
 * Gets class of the specified field at the specified index from the DataProvider.
 *
 * @param	i				index of desired class
 * @param	FieldName		tag for this type of upgrade e.g. 'Weapons' or 'Upgrades'
 *
 * @return	the requested class, or none if not found
 */
function class<SentinelUpgrade> GetClassFromIndex(int i, name FieldName)
{
	local class<UpgradeList> UpgradeInfo;
	local class<SentinelUpgrade> NewClass;
	local string NewClassString;

	UpgradeInfo = Cannon.UpgradeManager.default.UpgradeDataStoreClass.static.GetUpgradeList(FieldName);
	NewClassString = UpgradeInfo.default.ClassNames[i];
	NewClass = class<SentinelUpgrade>(DynamicLoadObject(NewClassString, class'Class'));

	return NewClass;
}

//Double-clicking a list applies the upgrade.
function OnList_DoubleClick(UIScreenObject EventObject, int InPlayerIndex)
{
	OnButtonBar_Apply(EventObject, InPlayerIndex);
}

function bool OnButtonBar_Close(UIScreenObject InButton, int InPlayerIndex)
{
	CloseScene(self);

	return true;
}

function bool OnButtonBar_Apply(UIScreenObject InButton, int InPlayerIndex)
{
	if(Deployer != none && SelectedUpgrade != none)
	{
		Deployer.DoUpgrade(SelectedUpgrade);
	}

	return true;
}

function bool OnButtonBar_Recycle(UIScreenObject InButton, int InPlayerIndex)
{
	local UTUIScene_MessageBox MessageBoxReference;
	local array<string> MessageBoxOptions;

	if(Deployer != none && Cannon != none && bOwnSentinel)
	{
		MessageBoxReference = GetMessageBoxScene();

		if(MessageBoxReference != none)
		{
			MessageBoxOptions.AddItem(class'UIStrings'.default.Recycle);
			MessageBoxOptions.AddItem("<Strings:UTGameUI.ButtonCallouts.Cancel>");

			MessageBoxReference.SetPotentialOptions(MessageBoxOptions);
			MessageBoxReference.Display(class'UIStrings'.default.RecycleConfimMessage,, OnButtonBar_Recycle_Confirm, 1);
		}
	}

	return true;
}

function OnButtonBar_Recycle_Confirm(UTUIScene_MessageBox MessageBox, int SelectedOption, int PlayerIndex)
{
	if(SelectedOption == 0)
	{
		Deployer.DoRecycle(Cannon);
		CloseScene(self);
	}
}

function bool OnButtonBar_Lock(UIScreenObject InButton, int InPlayerIndex)
{
	if(Cannon != none && bOwnSentinel)
	{
		Deployer.ToggleLock(Cannon);
		LockButton.SetDatastoreBinding(Cannon.bTeamUpgradeable ? class'UIStrings'.default.Lock : class'UIStrings'.default.Unlock);
	}

	return true;
}

function bool OnButtonBar_Configure(UIScreenObject InButton, int InPlayerIndex)
{
	local SentinelUpgrade UpgradeToConfigure;

	if(Cannon != none && SelectedUpgrade != none)
	{
		UpgradeToConfigure = Cannon.UpgradeManager.GetUpgrade(SelectedUpgrade);

		if(UpgradeToConfigure != none)
		{
			UpgradeToConfigure.OpenConfigurationMenuFor(GetUTPlayerOwner());
		}
	}

	return true;
}

function OnAvailableList_SubmitSelection(UIList Sender, optional int PlayerIndex=GetBestPlayerIndex())
{
	OnButtonBar_Apply(none, PlayerIndex);
}

function OnCurrentList_SubmitSelection(UIList Sender, optional int PlayerIndex=GetBestPlayerIndex())
{
	OnButtonBar_Configure(none, PlayerIndex);
}

function bool CloseScene(UIScene SceneToClose, optional bool bSkipKismetNotify, optional bool bSkipAnimation)
{
	local bool bResult;

	bResult = super.CloseScene(SceneToClose, bSkipKismetNotify, bSkipAnimation);

	if(bResult)
	{
		GetUTPlayerOwner().myHUD.bShowHUD = bOldShowHUD;
	}

	return bResult;
}

defaultproperties
{
}