//=============================================================================
// Tab page for ammo replacement options. Has a list to show classes that can
// be replaced, and controls next to it for configuring the replacement options
// for the selected class.
// https://mrevil.asvachin.eu/unreal/
//=============================================================================
class UTUITabPage_SentinelOptions_AmmoReplacement extends UTUITabPage_SentinelOptions;

var transient UIList ReplacedClassesList;
var transient UTUIComboBox ReplacementClass;
var transient UTUINumericEditBox ReplacementPercent;

var transient int CurrentReplacementInfoIndex; //TODO: The OnValueChanged delegate doesn't work for UINumericEditBoxes, so need to store this so that the value can be saved whenever the list selection changes.

var transient UTUIDataStore_AmmoReplacement AmmoReplacementDataStore;

var transient bool bDoneInitialActivation;

function PostInitialize()
{
	super.PostInitialize();

	if(!bDoneInitialActivation)
	{
		SetDataStoreBinding(class'UIStrings'.default.AmmoReplacementTabTitle);

		UILabel(FindChild('UILabel_ReplacedClasses', true)).SetDataStoreBinding(class'UIStrings'.default.ReplacedPickups);
		ReplacedClassesList = UIList(FindChild('UIList_ReplacedClasses', true));
		ReplacedClassesList.OnValueChanged = OnReplacedClassesChanged;

		UILabel(FindChild('UILabel_ReplacementClass', true)).SetDataStoreBinding(class'UIStrings'.default.ReplacementClasses);
		ReplacementClass = UTUIComboBox(FindChild('UTUIComboBox_ReplacementClass', true));
		ReplacementClass.OnValueChanged = OnReplacementClassChanged;

		UILabel(FindChild('UILabel_ReplacementPercent', true)).SetDataStoreBinding(class'UIStrings'.default.ReplacementPercent);
		ReplacementPercent = UTUINumericEditBox(FindChild('UTUINumericEditBox_ReplacementPercent', true));

		InitializeListDataStore();

		bDoneInitialActivation = true;
	}
}

function InitializeListDataStore()
{
	local DataStoreClient DSClient;

	DSClient = class'UIInteraction'.static.GetDataStoreClient();

	if(DSClient != none)
	{
		if(AmmoReplacementDataStore == none)
		{
			AmmoReplacementDataStore = UTUIDataStore_AmmoReplacement(UTUIScene(GetScene()).FindDataStore(class'UTUIDataStore_AmmoReplacement'.default.Tag));

			if(AmmoReplacementDataStore == none)
			{
				AmmoReplacementDataStore = DSClient.CreateDataStore(class'UTUIDataStore_AmmoReplacement');

				if(AmmoReplacementDataStore != none)
				{
					DSClient.RegisterDataStore(AmmoReplacementDataStore);
				}
			}
		}

		if(AmmoReplacementDataStore != none)
		{
			AmmoReplacementDataStore.FillListFrom(MutatorClass.default.ReplacedPickups);
		}
		else
		{
			`warn("Failed to find or create AmmoReplacementDataStore");
		}
	}
}

/**
 * Returns the index into MutatorClass.ReplacedPickups of the ReplacementInfo associated with the item selected in the ReplacedClasses list.
 */
function int FindSelectedReplacementInfoIndex()
{
	local String ReplacedClass;
	local int i;
	local int ReplacementInfoIndex;

	ReplacedClass = ReplacedClassesList.GetElementValue(ReplacedClassesList.GetCurrentItem());
	ReplacementInfoIndex = INDEX_NONE;

	for(i = 0; i < MutatorClass.default.ReplacedPickups.length; i++)
	{
		if(String(MutatorClass.default.ReplacedPickups[i].PickupClass) == ReplacedClass)
		{
			ReplacementInfoIndex = i;

			break;
		}
	}

	return ReplacementInfoIndex;
}

function OnReplacedClassesChanged(UIObject Sender, int PlayerIndex)
{
	local array<String> AmmoSizeStrings;
	local String AmmoSizeString;

	OnReplacementPercentChanged(none, 0); //TODO: See note at CurrentReplacementInfoIndex. Stupid UI bugs.

	CurrentReplacementInfoIndex = FindSelectedReplacementInfoIndex();
	AmmoSizeStrings = AmmoReplacementDataStore.GetList('ReplacementClass');

	//Work out which ammo class the selected class is currently configured to be replaced with.
	foreach AmmoSizeStrings(AmmoSizeString)
	{
		if(InStr(AmmosizeString, "("$MutatorClass.default.ReplacedPickups[CurrentReplacementInfoIndex].ReplacementClass.default.AmmoAmount$")") != INDEX_NONE)
		{
			ReplacementClass.SetSelectedItem(ReplacementClass.ComboList.FindItemIndex(AmmosizeString));
		}
	}

	ReplacementPercent.SetNumericValue(MutatorClass.default.ReplacedPickups[CurrentReplacementInfoIndex].ReplacementPercent);
}

function OnReplacementClassChanged(UIObject Sender, int PlayerIndex)
{
	local String AmmoSizeString;

	if(bDoneInitialActivation)
	{
		if(CurrentReplacementInfoIndex != INDEX_NONE)
		{
			AmmoSizeString = ReplacementClass.ComboEditbox.GetValue();

			//This code is terrible.
			if(InStr(AmmosizeString, "Small") != INDEX_NONE)
			{
				MutatorClass.default.ReplacedPickups[CurrentReplacementInfoIndex].ReplacementClass = class'UTAmmo_SentinelDeployer_Small';
			}
			else if(InStr(AmmosizeString, "Medium") != INDEX_NONE)
			{
				MutatorClass.default.ReplacedPickups[CurrentReplacementInfoIndex].ReplacementClass = class'UTAmmo_SentinelDeployer_Medium';
			}
			else if(InStr(AmmosizeString, "Large") != INDEX_NONE)
			{
				MutatorClass.default.ReplacedPickups[CurrentReplacementInfoIndex].ReplacementClass = class'UTAmmo_SentinelDeployer';
			}
		}
	}
}

function OnReplacementPercentChanged(UIObject Sender, int PlayerIndex)
{
	if(bDoneInitialActivation)
	{
		if(CurrentReplacementInfoIndex != INDEX_NONE)
		{
			MutatorClass.default.ReplacedPickups[CurrentReplacementInfoIndex].ReplacementPercent = ReplacementPercent.GetNumericValue();
		}
	}
}

function Commit()
{
	//The OnValueChanged delegate doesn't work for UINumericEditBoxes, so pretend the value changed here.
	OnReplacementPercentChanged(none, 0);

	super.Commit();
}

defaultproperties
{
	CurrentReplacementInfoIndex=INDEX_NONE
}